isDataBound property

  1. @override
bool get isDataBound
override

Whether this column is backed by a dataset field.

Standard columns are field-bound. UI-only columns such as action columns override this to opt out of dataset field binding, sorting, filtering, searching and validation metadata lookups.

Implementation

@override
bool get isDataBound => false;