FdcAggregate enum

Built-in aggregate operations shared by data-aware FDC components.

Numeric values can generally use sum, min, max, and avg. Date/date-time values generally support min and max. Individual components decide how to render unsupported aggregate/type combinations.

Inheritance
Available extensions

Values

sum → const FdcAggregate

Sum of all non-null values.

min → const FdcAggregate

Minimum non-null value.

max → const FdcAggregate

Maximum non-null value.

avg → const FdcAggregate

Arithmetic mean of non-null numeric values.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FdcAggregate>
A constant List of the values in this enum, in order of their declaration.