badgeColorBuilder property
Optional callback that derives badge color from the cell value.
Implementation
final FdcBadgeColorBuilder<T>? badgeColorBuilder;
Optional callback that derives badge color from the cell value.
final FdcBadgeColorBuilder<T>? badgeColorBuilder;