badgeTextBuilder property
Optional callback that derives badge text from the cell value.
Implementation
final FdcBadgeTextBuilder<T>? badgeTextBuilder;
Optional callback that derives badge text from the cell value.
final FdcBadgeTextBuilder<T>? badgeTextBuilder;