FdcCalculatedFieldValue typedef
FdcCalculatedFieldValue =
Object? Function(FdcRowContext context)
Computes the value of a calculated field for the supplied row.
The dataset calls this callback while materializing or refreshing calculated
values. Read source fields from FdcRowContext; do not write dataset state
from the callback. Return null when the calculated value is null.
Implementation
typedef FdcCalculatedFieldValue = Object? Function(FdcRowContext context);