backgroundColor property
Resolved cell background color, including read-only/disabled/selected state when the active grid style defines one.
Implementation
final Color? backgroundColor;
Resolved cell background color, including read-only/disabled/selected state when the active grid style defines one.
final Color? backgroundColor;