comboMaxPopupItems property
Maximum number of options shown in the combo filter popup before scrolling.
Implementation
final int comboMaxPopupItems;
Maximum number of options shown in the combo filter popup before scrolling.
final int comboMaxPopupItems;