allowAggregateChange property
Enables the summary row cell popup menu that lets users change this column's active aggregate at runtime.
Implementation
final bool allowAggregateChange;
Enables the summary row cell popup menu that lets users change this column's active aggregate at runtime.
final bool allowAggregateChange;