label property
Optional label displayed next to this column's summary value.
The label is shown when it is explicitly configured and the column has an active summary aggregate. Runtime aggregate changes replace this label only while a different aggregate is selected. When the user selects the column's configured aggregate again, this label is restored.
Implementation
final String? label;