showSelectedOptionCheckmark property
Shows a check mark beside the currently selected combo option.
Implementation
final bool showSelectedOptionCheckmark;
Shows a check mark beside the currently selected combo option.
final bool showSelectedOptionCheckmark;