errorIndicator property
Configures how validation errors are presented by this editor.
Implementation
final FdcErrorIndicatorOptions errorIndicator;
Configures how validation errors are presented by this editor.
final FdcErrorIndicatorOptions errorIndicator;