FdcComboSearchOptions class
Search configuration for combo editors and combo grid columns.
Constructors
- FdcComboSearchOptions({bool searchable = false, bool searchableInline = false, FdcComboSearchMode mode = FdcComboSearchMode.startsWith})
-
Creates a FdcComboSearchOptions.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- mode → FdcComboSearchMode
-
Defines how option labels are matched.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchable → bool
-
Shows a search text field inside the popup.
final
- searchableInline → bool
-
Enables type-to-search while the popup list has focus.
final
Methods
-
copyWith(
{bool? searchable, bool? searchableInline, FdcComboSearchMode? mode}) → FdcComboSearchOptions - Creates a copy with selected values replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override