effectiveEditor property
Built-in editor mode used when this column enters edit state.
Implementation
@override
FdcEditorType get effectiveEditor => FdcEditorType.custom;
Built-in editor mode used when this column enters edit state.
@override
FdcEditorType get effectiveEditor => FdcEditorType.custom;