FdcDataAdapterFilterOperator enum
Operators that an adapter may receive in FdcDataAdapterFilter.
Custom adapters should validate requested operators against their declared
FdcDataAdapterCapabilities before translating them to backend queries.
Values
- equals → const FdcDataAdapterFilterOperator
-
Equals option.
- notEquals → const FdcDataAdapterFilterOperator
-
Not equals option.
- contains → const FdcDataAdapterFilterOperator
-
Contains option.
- startsWith → const FdcDataAdapterFilterOperator
-
Starts with option.
- endsWith → const FdcDataAdapterFilterOperator
-
Ends with option.
- greaterThan → const FdcDataAdapterFilterOperator
-
Greater than option.
- greaterThanOrEqual → const FdcDataAdapterFilterOperator
-
Greater than or equal option.
- lessThan → const FdcDataAdapterFilterOperator
-
Less than option.
- lessThanOrEqual → const FdcDataAdapterFilterOperator
-
Less than or equal option.
- inList → const FdcDataAdapterFilterOperator
-
In list option.
- notInList → const FdcDataAdapterFilterOperator
-
Not in list option.
- isEmpty → const FdcDataAdapterFilterOperator
-
Is empty option.
- isNotEmpty → const FdcDataAdapterFilterOperator
-
Is not empty option.
- isNull → const FdcDataAdapterFilterOperator
-
Is null option.
- isNotNull → const FdcDataAdapterFilterOperator
-
Is not null option.
- isNullOrWhitespace → const FdcDataAdapterFilterOperator
-
Is null or whitespace option.
- isNotNullOrWhitespace → const FdcDataAdapterFilterOperator
-
Is not null or whitespace option.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FdcDataAdapterFilterOperator> - A constant List of the values in this enum, in order of their declaration.