FdcDataAdapterSort class

Source-level ordering descriptor passed to a data adapter.

Adapter default sorts are used when the dataset has no active user sort; dataset sorts override that default ordering for the current query.

Constructors

FdcDataAdapterSort({required String fieldName, FdcSortType sortType = FdcSortType.ascending})
Creates a FdcDataAdapterSort.
const
FdcDataAdapterSort.asc(String fieldName)
Creates a FdcDataAdapterSort.
const
FdcDataAdapterSort.desc(String fieldName)
Creates a FdcDataAdapterSort.
const

Properties

fieldName String
Dataset field name associated with this object.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortType FdcSortType
Direction of this adapter ordering rule.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited