FdcDataAggregateItem class

One aggregate expression requested from an adapter.

The item identifies the field and aggregate function. Optional aliases allow multiple expressions to be correlated with result values.

Constructors

FdcDataAggregateItem({required String fieldName, required FdcAggregate aggregate})
Creates a FdcDataAggregateItem.
const

Properties

aggregate → FdcAggregate
Aggregate function to calculate for the field.
final
fieldName → String
Dataset field name associated with this object.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited