FdcDataApplyResult class sealed
Result returned by IFdcDataAdapter.applyUpdates().
A result is either FdcDataApplySuccess or FdcDataApplyFailure. The dataset uses it to confirm pending local state or restore rejected changes.
- Implementers
Constructors
-
FdcDataApplyResult({required bool success, Map<
int, Object> insertedKeys = const <int, Object>{}, Map<int, Map< serverRows = const <int, Map<String, Object?>>{}, List<String, Object?> >FdcDataApplyError> errors = const <FdcDataApplyError>[]}) -
Creates a FdcDataApplyResult.
factory
-
FdcDataApplyResult.failure({Map<
int, Object> ? insertedKeys, Map<int, Map< ? serverRows, List<String, Object?> >FdcDataApplyError> ? errors}) -
constfactory
-
FdcDataApplyResult.success({Map<
int, Object> ? insertedKeys, Map<int, Map< ? serverRows})String, Object?> > -
constfactory
Properties
-
errors
→ List<
FdcDataApplyError> -
Errors associated with this result.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
insertedKeys
→ Map<
int, Object> -
Backend-generated keys indexed by local record identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serverRows
→ Map<
int, Map< String, Object?> > -
Backend-confirmed row values indexed by local record identifier.
final
- success → bool
-
Whether the adapter accepted the complete apply request.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited