includeFields property

bool includeFields
final

Requests optional schema metadata from adapters that can provide it.

Dataset open APIs enable this automatically when the dataset was created without explicit fields. Adapters may ignore it when they cannot cheaply provide schema metadata.

Implementation

final bool includeFields;