includeTotalCount property
Whether adapters should compute and return FdcDataLoadResult.totalCount.
Paged datasets request an exact count when their paging options require it or when no dataset search is active. While search is active and an exact count is not required, they set this to false so expensive backends may skip the count query. Adapters may still return a cheap count when false.
Implementation
final bool includeTotalCount;