selectedKeysOnly property
Whether selectedKeys should be applied as an adapter-side include-only predicate. When true and selectedKeys is empty, adapters must return an empty result set.
Implementation
final bool selectedKeysOnly;
Whether selectedKeys should be applied as an adapter-side include-only predicate. When true and selectedKeys is empty, adapters must return an empty result set.
final bool selectedKeysOnly;