internalNextRowId property

int? internalNextRowId
final

Optional next internal row id for adapters that expose internalRowIds.

This lets datasets allocate new inserted records without colliding with adapter rows that were not included in a filtered/paged load result.

Implementation

final int? internalNextRowId;