infiniteLoadThreshold property

double infiniteLoadThreshold
final

Fraction of the currently loaded row extent that must be visible before an infinite-paging dataset preloads the next page.

The default value of 0.70 starts the request when the trailing edge of the grid viewport reaches approximately 70% of the loaded content.

Implementation

final double infiniteLoadThreshold;