isLocal property
bool
get
isLocal
True when this dataset owns its rows directly instead of using an adapter.
Implementation
bool get isLocal => _adapter == null;
True when this dataset owns its rows directly instead of using an adapter.
bool get isLocal => _adapter == null;