isNotEmpty property
bool
get
isNotEmpty
Whether the current dataset view contains one or more records.
Implementation
bool get isNotEmpty => recordCount != 0;
Whether the current dataset view contains one or more records.
bool get isNotEmpty => recordCount != 0;