FdcDataSetAfterClose typedef
FdcDataSetAfterClose =
void Function(FdcDataSet dataSet)
Called after records, query state, selection, paging state, and edit buffers have been cleared and the dataset has entered the closed state.
This callback is notification-only with respect to the completed close; throwing does not restore the previous dataset contents.
Implementation
typedef FdcDataSetAfterClose = void Function(FdcDataSet dataSet);