avg method

FdcDecimal? avg(
  1. String fieldName
)

Calculates the average for a numeric field over the current flat dataset view.

Null values are skipped. Returns null when the current view contains no non-null values for fieldName.

Implementation

FdcDecimal? avg(String fieldName) =>
    _dataSet._aggregateCached(fieldName, FdcAggregate.avg) as FdcDecimal?;