calculate method

Calculates adapter/query aggregates for the current logical dataset result.

In non-paged/local mode this uses the normal local aggregate path over the current filtered view. In paged adapter mode, the adapter must calculate aggregates over the full matching result set without LIMIT/OFFSET.

Implementation

Future<FdcDataAggregateResult> calculate(
  List<FdcDataAggregateItem> aggregates,
) => _dataSet._aggregateQuery(aggregates);