FdcDataSetBeforeInsert typedef

FdcDataSetBeforeInsert = void Function(FdcDataSet dataSet)

Called before an inserted record is added to the record store or activated.

Throw FdcDataSetAbortException to veto the insert. Defaults have not yet been applied when this callback runs.

Implementation

typedef FdcDataSetBeforeInsert = void Function(FdcDataSet dataSet);