FdcDataSetBookmark class final

An immutable position marker for a record in an FdcDataSet.

Bookmarks are scoped to the dataset instance that created them. They are transient runtime objects: they are not serializable and cannot be used to position another dataset instance.

Annotations

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited