isNotEmpty property
bool
get
isNotEmpty
True when at least one error message is available.
Implementation
bool get isNotEmpty => _dataSet._errorStore.isNotEmpty;
True when at least one error message is available.
bool get isNotEmpty => _dataSet._errorStore.isNotEmpty;