FdcDataSetException class

Base exception for dataset and adapter operation failures.

The exception keeps stable operation and code values plus a user-facing message so UI and logging layers do not need to parse backend exception text.

Implemented types
Implementers

Constructors

FdcDataSetException({required String message, List<FdcDataSetError> errors = const <FdcDataSetError>[], Object? cause})
Creates a FdcDataSetException.
const

Properties

cause Object?
Original exception or backend object that caused this error.
final
errors List<FdcDataSetError>
Errors associated with this result.
final
hashCode int
The hash code for this object.
no setterinherited
message String
User-facing message text.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited