selected property

bool? selected
final

Optional row-state selector used by the fluent filter DSL.

When set, the dataset view only contains records whose internal selection state matches this value. This is not a field filter and does not mutate selection state.

Implementation

final bool? selected;