selectedFilter property
bool?
get
selectedFilter
Active row-selection-state filter, or null when no selection filter is
applied.
Implementation
bool? get selectedFilter => context.selected;
Active row-selection-state filter, or null when no selection filter is
applied.
bool? get selectedFilter => context.selected;