FdcDataSetOperationExecutionMode enum

How long-running dataset work should execute.

auto keeps small operations inline and lets the dataset move supported large operations to a background isolate when that improves UI responsiveness.

Inheritance
Available extensions

Values

auto → const FdcDataSetOperationExecutionMode

Chooses the execution strategy automatically.

inline → const FdcDataSetOperationExecutionMode

Executes the operation on the current isolate.

isolate → const FdcDataSetOperationExecutionMode

Executes the operation on a worker isolate when supported.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FdcDataSetOperationExecutionMode>
A constant List of the values in this enum, in order of their declaration.