isolateSortThreshold property
Minimum view row count before the automatic policy attempts isolate sorting.
Implementation
final int isolateSortThreshold;
Minimum view row count before the automatic policy attempts isolate sorting.
final int isolateSortThreshold;