sortValueCacheSize property

int sortValueCacheSize
final

Maximum number of sort fields to keep in the sort value/rank cache.

The cache is intentionally small by default because large datasets can make normalized value/rank arrays expensive in memory.

Implementation

final int sortValueCacheSize;