firstPage method
Loads the first page of the active adapter query.
Implementation
Future<void> firstPage() => _dataSet._pagingCoordinator.firstPage();
Loads the first page of the active adapter query.
Future<void> firstPage() => _dataSet._pagingCoordinator.firstPage();