hasPriorPage property

bool get hasPriorPage

True when paging is enabled and the active page is not the first page.

This is always false when paging is disabled or the dataset is closed. In infinite paging mode it refers to the last successfully loaded page index, even though earlier pages remain retained in the dataset.

Implementation

bool get hasPriorPage => _dataSet._pagingCoordinator.hasPreviousPage;