lastPage method
Loads the last page when the adapter reported a total count.
Implementation
Future<void> lastPage() => _dataSet._pagingCoordinator.lastPage();
Loads the last page when the adapter reported a total count.
Future<void> lastPage() => _dataSet._pagingCoordinator.lastPage();