pageCount property

int? get pageCount

Total page count for the active query, or null when the adapter did not report a total count.

Implementation

int? get pageCount => _dataSet._pagingCoordinator.pageCount;