active property
bool
get
active
True when the dataset has an active global search criterion.
Implementation
bool get active => state.isActive;
True when the dataset has an active global search criterion.
bool get active => state.isActive;