clear method
Clears the active global search and restores the unsearched query/view.
Implementation
Future<void> clear() {
return _clearSearch();
}
Clears the active global search and restores the unsearched query/view.
Future<void> clear() {
return _clearSearch();
}