count property
int
get
count
Number of selected rows in the current dataset view.
Implementation
int get count => _dataSet._selectionCoordinator.selectedCount;
Number of selected rows in the current dataset view.
int get count => _dataSet._selectionCoordinator.selectedCount;