isEmpty property
bool
get
isEmpty
Returns whether no rows are selected in the current dataset view.
Implementation
bool get isEmpty => count == 0;
Returns whether no rows are selected in the current dataset view.
bool get isEmpty => count == 0;