isNotEmpty property
bool
get
isNotEmpty
Returns whether at least one row is selected in the current dataset view.
Implementation
bool get isNotEmpty => count > 0;
Returns whether at least one row is selected in the current dataset view.
bool get isNotEmpty => count > 0;