FdcDataSetState enum

Current lifecycle/editing state of an FdcDataSet.

Inheritance
Available extensions

Values

closed → const FdcDataSetState

The dataset is closed and has no active records.

browse → const FdcDataSetState

The dataset is open for browsing without an active edit operation.

edit → const FdcDataSetState

The current record is being edited.

insert → const FdcDataSetState

A new record is being inserted or appended.

loading → const FdcDataSetState

The dataset is loading data from its source or adapter.

applyingUpdates → const FdcDataSetState

Posted changes are being applied through the adapter.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FdcDataSetState>
A constant List of the values in this enum, in order of their declaration.