error property
Object?
get
error
Last captured work error, if the most recent transition failed.
Implementation
Object? get error => _error;
Last captured work error, if the most recent transition failed.
Object? get error => _error;