isWorking property
bool
get
isWorking
Whether the dataset is currently performing a reported work operation.
Implementation
bool get isWorking => _isWorking;
Whether the dataset is currently performing a reported work operation.
bool get isWorking => _isWorking;