operator == method
The equality operator.
The default behavior for all Objects is to return true if and
only if this object and other are the same object.
Override this method to specify a different equality relation on a class. The overriding method must still be an equivalence relation. That is, it must be:
-
Total: It must return a boolean for all arguments. It should never throw.
-
Reflexive: For all objects
o,o == omust be true. -
Symmetric: For all objects
o1ando2,o1 == o2ando2 == o1must either both be true, or both be false. -
Transitive: For all objects
o1,o2, ando3, ifo1 == o2ando2 == o3are true, theno1 == o3must be true.
The method should also be consistent over time, so whether two objects are equal should only change if at least one of the objects was modified.
If a subclass overrides the equality operator, it should override the hashCode method as well to maintain consistency.
Implementation
@override
bool operator ==(Object other) {
// Equality is intentionally restricted to FdcDecimal values. Accepting
// Dart num here would make equality asymmetric because int/double do not
// know how to compare themselves back to FdcDecimal, and it would also
// break the ==/hashCode contract for Set/Map keys. Use comparison
// operators or convert the literal with `.decimal` for numeric checks.
return other is FdcDecimal && compareTo(other) == 0;
}