FdcDefaultTranslationResolver class
Default built-in FDC translation resolver.
Resolves built-in FDC translation locales by language code and falls back to FdcTranslations.enUs for all other locales.
- Implemented types
Constructors
- FdcDefaultTranslationResolver()
-
Creates the default FDC translation resolver.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
Locale locale) → FdcTranslations -
Resolves translations for
locale.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited