FdcDialogTranslations class

Dialog text resources.

Constructors

FdcDialogTranslations({String confirmDelete = 'Confirm delete', String deleteCurrentRecord = 'Delete current record?'})
Creates dialog translations.
const

Properties

confirmDelete → String
Delete confirmation dialog title.
final
deleteCurrentRecord → String
Delete confirmation dialog message.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited