FdcEditorTheme class

Optional Flutter ThemeExtension bridge for FDC editors.

Without an explicit FDC editor theme, the built-in light/dark preset follows the active Material ThemeData.brightness.

Inheritance

Constructors

FdcEditorTheme({FdcEditorThemeData data = FdcEditorThemes.light, FdcEditorInputStyle? style})
Creates a FdcEditorTheme.
const

Properties

data → FdcEditorThemeData
Base editor theme data provided by this ThemeExtension.
final
effectiveData → FdcEditorThemeData
Theme data after merging the optional root style override.
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → FdcEditorInputStyle?
Optional root editor input style override merged over data.input.
final
type → Object
The extension's type.
no setterinherited

Methods

copyWith({FdcEditorThemeData? data, FdcEditorInputStyle? style}) → FdcEditorTheme
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<FdcEditorTheme>? other, double t) → FdcEditorTheme
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

resolveComboPopupStyle(BuildContext context, {FdcEditorThemeData? localTheme, FdcEditorComboPopupStyle? localStyle}) → FdcEditorComboPopupStyle
Resolves the effective combo-popup style for an editor.
resolveControlsStyle(BuildContext context, {FdcEditorThemeData? localTheme, FdcEditorControlsStyle? localStyle}) → FdcEditorControlsStyle
Resolves the effective non-text control style for an editor.
resolveData(BuildContext context, FdcEditorThemeData? localTheme) → FdcEditorThemeData
Resolves editor theme data using local, FDC subtree, Material bridge, and built-in fallbacks.
resolveInputStyle(BuildContext context, {FdcEditorThemeData? localTheme, FdcEditorInputStyle? localStyle}) → FdcEditorInputStyle
Resolves the effective text-input style for an editor.