FdcErrorIndicatorMode enum

Selects how a component presents validation/data-entry errors.

Editors support all modes. Grid cells support none and marker; using inline in grid cell indicator options is rejected by debug assertions.

Inheritance
Available extensions

Values

none → const FdcErrorIndicatorMode

Do not render an error indicator.

marker → const FdcErrorIndicatorMode

Render a compact marker for the validation error.

inline → const FdcErrorIndicatorMode

Render the validation message inline.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FdcErrorIndicatorMode>
A constant List of the values in this enum, in order of their declaration.