textAlignment property
Preferred text alignment for writers that render positioned text.
Implementation
final FdcExportTextAlignment textAlignment;
Preferred text alignment for writers that render positioned text.
final FdcExportTextAlignment textAlignment;