scope property
Selects which dataset rows are included when exporting through
FdcExporter.exportDataSet.
Implementation
final FdcExportScope scope;
Selects which dataset rows are included when exporting through
FdcExporter.exportDataSet.
final FdcExportScope scope;