valueMode property
Controls whether writers preserve typed values where possible or convert them to display-oriented text.
Implementation
final FdcExportValueMode valueMode;
Controls whether writers preserve typed values where possible or convert them to display-oriented text.
final FdcExportValueMode valueMode;