FdcExportPayload class sealed

Serialized content produced by an FdcExportWriter.

Consumers can always read bytes. text is non-null only for textual payloads.

Implementers

Properties

bytes Uint8List
Serialized bytes for this payload.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
Text content, or null when the payload is binary.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited