writerFor static method
Returns the writer registered for format, or null when none exists.
Implementation
static FdcExportWriter? writerFor(FdcExportFormat format) => _writers[format];
Returns the writer registered for format, or null when none exists.
static FdcExportWriter? writerFor(FdcExportFormat format) => _writers[format];