textOrNull property
String?
get
textOrNull
Text content, or null for binary formats such as PDF.
Implementation
String? get textOrNull => payload.text;
Text content, or null for binary formats such as PDF.
String? get textOrNull => payload.text;