FdcExportScope enum

Row scope used by dataset/grid export operations.

Inheritance
Available extensions

Values

allRows → const FdcExportScope

Export all non-deleted dataset rows, ignoring the current filter/sort/search view.

currentView → const FdcExportScope

Export the current dataset view, respecting filter, sort and search state.

selectedRows → const FdcExportScope

Export selected rows from the current dataset view.

currentRow → const FdcExportScope

Export only the current dataset row.

changedRows → const FdcExportScope

Export pending cached-update rows from FdcDataSet.changeSet.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FdcExportScope>
A constant List of the values in this enum, in order of their declaration.