FdcExportValueFormatter typedef
Formats a source value as presentation text for presentation-oriented writers.
The formatter is typically supplied by a grid column so exports such as PDF can preserve the same display formatting, prefixes and suffixes shown in the UI.
Implementation
typedef FdcExportValueFormatter = String Function(Object? value);