formatValueOf method

String formatValueOf(
  1. String fieldName, [
  2. Object? value
])

Formats another field value from the same row using its dataset schema.

When value is omitted, the current row value is resolved first.

Implementation

String formatValueOf(String fieldName, [Object? value]) {
  _requireField(fieldName, 'FdcFieldContext.formatValueOf');
  return _fieldValueFormatter(
    fieldName,
    value ?? _fieldValueResolver(fieldName),
  );
}