isKey property

bool isKey
final

Whether this field participates in the dataset record identity.

Multiple fields with isKey set form one composite identity, in field declaration order.

Implementation

final bool isKey;