FdcFieldValueChangeReplacement<T> class final

Accepts a field change but substitutes a different value.

Inheritance

Constructors

FdcFieldValueChangeReplacement(T? replacementValue, {Map<String, Object?> additionalValues = const <String, Object?>{}})
Creates a result that replaces the proposed value.
const

Properties

accepted bool
Whether the proposed value change should proceed.
no setteroverride
additionalValues Map<String, Object?>
Related field values to apply with the primary value change.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasReplacement bool
Whether value replaces the originally proposed value.
no setteroverride
message String?
User-facing message text.
finalinherited
replacementValue → T?
Replacement value that should be committed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T?
Replacement value when hasReplacement is true.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withAdditionalValues(Map<String, Object?> values) FdcFieldValueChangeResult<T>
Returns the same decision enriched with related field updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited