withAdditionalValues abstract method
Returns the same decision enriched with related field updates.
Implementation
FdcFieldValueChangeResult<T> withAdditionalValues(
Map<String, Object?> values,
);
Returns the same decision enriched with related field updates.
FdcFieldValueChangeResult<T> withAdditionalValues(
Map<String, Object?> values,
);