oldValue property
T?
oldValue
final
Logical field value before the proposed or completed change.
Implementation
final T? oldValue;
Logical field value before the proposed or completed change.
final T? oldValue;