additionalValueSnapshot property
Immutable snapshot of related field updates staged with setValueOf.
Implementation
Map<String, Object?> get additionalValueSnapshot =>
Map<String, Object?>.unmodifiable(_additionalValues);
Immutable snapshot of related field updates staged with setValueOf.
Map<String, Object?> get additionalValueSnapshot =>
Map<String, Object?>.unmodifiable(_additionalValues);