newValue property
T?
newValue
final
Proposed logical value before the change decision is applied.
Implementation
final T? newValue;
Proposed logical value before the change decision is applied.
final T? newValue;