FdcFieldValueFormatter typedef

FdcFieldValueFormatter = String Function(String fieldName, Object? value)

Formats a field value by dataset field name.

Custom cells use this callback when they need the grid's normal field-aware display formatting without rendering a standard cell. Keep it side-effect free because formatting may occur repeatedly during rebuilds.

Implementation

typedef FdcFieldValueFormatter =
    String Function(String fieldName, Object? value);