selected method
Adds a row-selection-state filter to the dataset query.
This filters the current view by the internal record selection state; it does not select or unselect records. Like field conditions, it must be declared before orderBy().
Implementation
@useResult
FdcFilterBuilder selected(bool value) {
_ensureCanAddFilterCondition();
_context = _context.copyWith(selected: value);
return this;
}