selectedFilter property
bool?
get
selectedFilter
Built row-selection-state filter, or null when no selection filter is
part of the builder.
Implementation
bool? get selectedFilter => _context.selected;
Built row-selection-state filter, or null when no selection filter is
part of the builder.
bool? get selectedFilter => _context.selected;