FdcFocusScope class

Subtree-level FDC focus options provider.

Use FdcApp.focus for app-wide defaults. Use FdcFocusScope around a specific form or panel when it needs different focus traversal behavior.

Inheritance

Constructors

FdcFocusScope({Key? key, FdcFocusOptions options = const FdcFocusOptions(), required Widget child})
Creates a FdcFocusScope.
const

Properties

child Widget
Child widget rendered by this configuration.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
options FdcFocusOptions
Options used by this configuration.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

maybeOf(BuildContext context) FdcFocusOptions?
Returns the nearest scoped focus options and subscribes to scope changes.
maybeOfNonListening(BuildContext context) FdcFocusOptions?
Returns the nearest scoped focus options without subscribing to updates.
of(BuildContext context) FdcFocusOptions
Returns the nearest scoped focus options, or suite defaults when no scope exists.