Resolves FDC data-entry formats from a Flutter locale.
Implementations should be deterministic and synchronous. They should not depend on asynchronous locale initialization.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
Locale locale) → FdcFormatSettings -
Resolves format settings for
locale. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited