FdcFormatSettings class

Formatting settings applied to flutter_data_components widgets.

The default const constructor is the neutral technical fallback for headless/test scenarios and locales that are not covered by the built-in curated FDC locale registry. Application-level settings supplied through FdcApp.formatSettings always remain authoritative.

Constructors

FdcFormatSettings({String? locale, String dateFormat = _neutralDateFormat, String timeFormat = _neutralTimeFormat, String? dateTimeFormat, String decimalSeparator = _neutralDecimalSeparator, String thousandSeparator = _neutralThousandSeparator, bool showThousandSeparator = _neutralShowThousandSeparator})
Creates a FdcFormatSettings.
const
FdcFormatSettings.fromLocale(Locale locale)
Creates FDC format settings for the supplied locale.
factory
FdcFormatSettings.system()
Creates FDC format settings for the current platform locale.
factory

Properties

dateFormat → String
Pattern used to format date values.
final
dateTimeFormat → String?
Pattern used to format date-time values.
final
decimalSeparator → String
Character used as the decimal separator.
final
effectiveDateTimeFormat → String
Returns the current effective date time format.
no setter
hashCode → int
The hash code for this object.
no setteroverride
locale → String?
Locale associated with these settings.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showThousandSeparator → bool
Whether show thousand separator.
final
thousandSeparator → String
Character used as the thousands separator.
final
timeFormat → String
Pattern used to format time values.
final

Methods

copyWith({Object? locale = _fdcUnsetFormatSettingsValue, String? dateFormat, String? timeFormat, Object? dateTimeFormat = _fdcUnsetFormatSettingsValue, String? decimalSeparator, String? thousandSeparator, bool? showThousandSeparator}) → FdcFormatSettings
Returns a copy with changed format settings.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveLocaleOnlyPreset() → FdcFormatSettings
Returns locale preset settings when this instance only carries a locale.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override