FdcGridCellChangedContext typedef
Grid specialization of the context delivered after an accepted cell change.
Implementation
typedef FdcGridCellChangedContext = FdcFieldValueChangedContext<Object?>;
Grid specialization of the context delivered after an accepted cell change.
typedef FdcGridCellChangedContext = FdcFieldValueChangedContext<Object?>;