FdcGridCellFocusEventContext typedef
Grid specialization of focus context used by cell enter/exit callbacks.
Implementation
typedef FdcGridCellFocusEventContext = FdcFieldFocusContext<Object?>;
Grid specialization of focus context used by cell enter/exit callbacks.
typedef FdcGridCellFocusEventContext = FdcFieldFocusContext<Object?>;