autoSizeMode property
Automatic width behavior used when the grid viewport changes size.
Implementation
final FdcGridColumnAutoSizeMode autoSizeMode;
Automatic width behavior used when the grid viewport changes size.
final FdcGridColumnAutoSizeMode autoSizeMode;