effectiveEditor property
FdcEditorType
get
effectiveEditor
Built-in editor mode used when this column enters edit state.
Implementation
FdcEditorType get effectiveEditor;
Built-in editor mode used when this column enters edit state.
FdcEditorType get effectiveEditor;