isDataBound property

bool get isDataBound

Whether this column is backed by a dataset field.

Standard columns are field-bound. UI-only columns such as action columns override this to opt out of dataset field binding, sorting, filtering, searching and validation metadata lookups.

Implementation

bool get isDataBound => true;