FdcGridColumnAutoSizeMode enum

How a grid column participates in automatic width changes.

none keeps the column width fixed except for explicit/manual resize. viewport lets the column absorb grid viewport width deltas. This is a layout auto-size mode, not content measurement, and pinned columns are not considered by the scrollable viewport auto-size pass.

Inheritance
Available extensions

Values

none → const FdcGridColumnAutoSizeMode

Do not auto-size the column.

viewport → const FdcGridColumnAutoSizeMode

Let the column absorb viewport width deltas.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FdcGridColumnAutoSizeMode>
A constant List of the values in this enum, in order of their declaration.