FdcGridColumnFocusEventContext typedef
Grid specialization of focus context used by column enter/exit callbacks.
Implementation
typedef FdcGridColumnFocusEventContext = FdcFieldFocusContext<Object?>;
Grid specialization of focus context used by column enter/exit callbacks.
typedef FdcGridColumnFocusEventContext = FdcFieldFocusContext<Object?>;