verticalSeparatorColor property
Trailing vertical separator color used by this group header cell.
Implementation
final Color? verticalSeparatorColor;
Trailing vertical separator color used by this group header cell.
final Color? verticalSeparatorColor;