isPinned property
bool
get
isPinned
Whether this mode places the column in either pinned region.
Implementation
bool get isPinned => isStart || isEnd;
Whether this mode places the column in either pinned region.
bool get isPinned => isStart || isEnd;