FdcGridColumnPinning class

Configures interactive column pinning and labels for pinned header bands.

Constructors

FdcGridColumnPinning({bool enabled = false, String startPinnedGroupLabel = '', String unpinnedGroupLabel = '', String endPinnedGroupLabel = ''})
Creates a FdcGridColumnPinning.
const

Properties

enabled → bool
Controls whether column pin/unpin actions are available in grid menus.
final
endPinnedGroupLabel → String
Optional label rendered across the end-pinned header band while the column-group header row is active.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startPinnedGroupLabel → String
Optional label rendered across the start-pinned header band while the column-group header row is active.
final
unpinnedGroupLabel → String
Optional label rendered across ungrouped columns in the scrollable header band while the column-group header row is active.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override