unpinnedGroupLabel property
Optional label rendered across ungrouped columns in the scrollable header band while the column-group header row is active.
Implementation
final String unpinnedGroupLabel;
Optional label rendered across ungrouped columns in the scrollable header band while the column-group header row is active.
final String unpinnedGroupLabel;