dispose method
void
dispose()
Detaches this controller and prevents it from being attached again.
Implementation
void dispose() {
if (_disposed) {
return;
}
detach();
_disposed = true;
}
Detaches this controller and prevents it from being attached again.
void dispose() {
if (_disposed) {
return;
}
detach();
_disposed = true;
}