isAttached property
bool
get
isAttached
Whether this controller is currently attached to a live grid instance.
Implementation
bool get isAttached => _capture != null;
Whether this controller is currently attached to a live grid instance.
bool get isAttached => _capture != null;