layoutChanged method
Notifies the feature that the current grid layout has changed.
Implementation
@override
void layoutChanged() {
if (!isAttached || _disposed) {
return;
}
_layoutChangedCommand?.call();
}
Notifies the feature that the current grid layout has changed.
@override
void layoutChanged() {
if (!isAttached || _disposed) {
return;
}
_layoutChangedCommand?.call();
}