includeHeaders property
Includes column labels as the first row when the selected writer format supports headers.
Implementation
final bool includeHeaders;
Includes column labels as the first row when the selected writer format supports headers.
final bool includeHeaders;