writerOptions property
Per-format writer options applied only by this export button.
Implementation
final Map<FdcExportFormat, FdcExportWriterOptions> writerOptions;
Per-format writer options applied only by this export button.
final Map<FdcExportFormat, FdcExportWriterOptions> writerOptions;