labelTextStyle property
Text style used by the floating label.
Focused and unfocused label colors are applied over this style.
Implementation
final TextStyle? labelTextStyle;
Text style used by the floating label.
Focused and unfocused label colors are applied over this style.
final TextStyle? labelTextStyle;