initiallyVisible property

bool initiallyVisible
final

Controls whether the header filter row is visible when the grid starts.

Users can still show or hide the row at runtime through the grid menu while visible is true.

Implementation

final bool initiallyVisible;