visible property
Controls whether grid-managed column filters are available.
When this is false, the header filter row and its menu actions are disabled. Dataset-level filters can still be applied programmatically.
Implementation
final bool visible;
Controls whether grid-managed column filters are available.
When this is false, the header filter row and its menu actions are disabled. Dataset-level filters can still be applied programmatically.
final bool visible;