verticalSeparatorInset property
Symmetric inset used above and below vertical header column separators.
Set to zero to render header separators as flat full-height grid lines.
Implementation
final double? verticalSeparatorInset;
Symmetric inset used above and below vertical header column separators.
Set to zero to render header separators as flat full-height grid lines.
final double? verticalSeparatorInset;