FdcGridMenuContext class
Read-only context supplied to grid and column body-cell context menus.
Constructors
- FdcGridMenuContext({required BuildContext buildContext, required FdcDataSet dataSet, required FdcGridRowContext row, required int rowIndex, required int? sourceRowIndex, required int? recordId, required FdcGridColumn column, required int columnIndex, required Object? value, required bool isEditing, required bool isCellSelected, required bool isRowSelected, required bool canInsertRecord, required bool canAppendRecord, required bool canCancelEdit, required VoidCallback? insertRecord, required VoidCallback? appendRecord, required VoidCallback? cancelEdit})
-
Creates a FdcGridMenuContext.
const
Properties
- appendRecord → VoidCallback?
-
Starts a grid-owned append operation and focuses the first editable field.
final
- buildContext → BuildContext
-
Flutter build context associated with this object.
final
- canAppendRecord → bool
-
Whether the grid can append a new record from this menu context.
final
- canCancelEdit → bool
-
Whether the grid can cancel the current edit/insert buffer.
final
- cancelEdit → VoidCallback?
-
Cancels the current grid/dataset edit or insert operation.
final
- canInsertRecord → bool
-
Whether the grid can start an inserted record from this menu context.
final
- column → FdcGridColumn
-
Column configuration associated with this object.
final
- columnIndex → int
-
Zero-based column index in the current grid layout.
final
- dataSet → FdcDataSet
-
Dataset associated with this object.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- insertRecord → VoidCallback?
-
Starts a grid-owned insert operation and focuses the first editable field.
final
- isCellSelected → bool
-
Whether this exact cell is the current grid selection.
final
- isEditing → bool
-
Whether the grid is currently editing this cell.
final
- isRowSelected → bool
-
Whether the row is included in the grid row-selection set.
final
- recordId → int?
-
Internal record identifier.
final
- row → FdcGridRowContext
-
Row context associated with this object.
final
- rowIndex → int
-
Zero-based row index in the current view.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceRowIndex → int?
-
Source-adapter row index when available for this row.
final
- value → Object?
-
Current value carried by this object.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited