confirmDelete property
When true, Ctrl+Delete asks for confirmation before deleting the current record from the dataset.
Implementation
final bool confirmDelete;
When true, Ctrl+Delete asks for confirmation before deleting the current record from the dataset.
final bool confirmDelete;