rowHeight property
Fixed height used by data rows.
This value must be finite and at least minimumRowHeight. Runtime layout code uses resolvedRowHeight as a final safety net.
Implementation
final double rowHeight;
Fixed height used by data rows.
This value must be finite and at least minimumRowHeight. Runtime layout code uses resolvedRowHeight as a final safety net.
final double rowHeight;