FdcGridPagingNavigator.input constructor

const FdcGridPagingNavigator.input({
  1. String? id,
  2. bool visible = true,
  3. FdcGridItemPlacement placement = FdcGridItemPlacement.end,
  4. String? pageLabel,
  5. String? pageCountLabel,
  6. bool showFirstLastButtons = true,
  7. bool showPreviousNextButtons = true,
  8. bool allowPageInput = true,
})

Implementation

const FdcGridPagingNavigator.input({
  super.id,
  super.visible,
  super.placement = FdcGridItemPlacement.end,
  this.pageLabel,
  this.pageCountLabel,
  this.showFirstLastButtons = true,
  this.showPreviousNextButtons = true,
  this.allowPageInput = true,
}) : _style = _FdcGridPageNavigatorStyle.input,

     /// Maximum number of numbered page buttons shown at once.
     visiblePageCount = 5,

     /// Shows first and last page boundaries around the numbered page window.
     showBoundaryPages = true;