FdcGridResolvedCellIndicatorStyle class
Fully resolved paint values for the active-cell indicator border.
Constructors
- FdcGridResolvedCellIndicatorStyle({required Color color, required double thickness, BorderRadius? borderRadius})
-
Creates a FdcGridResolvedCellIndicatorStyle.
const
Properties
- borderRadius → BorderRadius?
-
The border radius.
final
- color → Color
-
The color.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thickness → double
-
The thickness.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override