FdcGridRowFocusEventContext typedef
Grid specialization of focus context used by row enter/exit callbacks.
Implementation
typedef FdcGridRowFocusEventContext = FdcFieldFocusContext<Object?>;
Grid specialization of focus context used by row enter/exit callbacks.
typedef FdcGridRowFocusEventContext = FdcFieldFocusContext<Object?>;