FdcGridRowIndicator class

Configures the leading grid region used for row status, numbering, selection, and the main menu.

Constructors

FdcGridRowIndicator({bool visible = true, FdcGridRowIndicatorOptions options = const FdcGridRowIndicatorOptions()})
Creates a FdcGridRowIndicator.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
options FdcGridRowIndicatorOptions
Configures the content shown inside the leading row indicator component.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible bool
Controls whether the leading row indicator component is rendered.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override