options property
Configures the content shown inside the leading row indicator component.
Implementation
final FdcGridRowIndicatorOptions options;
Configures the content shown inside the leading row indicator component.
final FdcGridRowIndicatorOptions options;