visible property
Controls whether the leading row indicator component is rendered.
The row indicator hosts row status, row numbers, row selection, and the main grid menu when enabled. When this is false, the main grid menu actions are exposed through each column header menu.
Implementation
final bool visible;