FdcGridSeparator constructor

FdcGridSeparator({
  1. String? id,
  2. bool visible = true,
  3. FdcGridItemPlacement placement = FdcGridItemPlacement.end,
  4. double width = 13,
  5. double height = 18,
  6. double thickness = 1,
  7. Color? color,
})

Creates a FdcGridSeparator.

Implementation

FdcGridSeparator({
  super.id,
  super.visible,
  super.placement,
  this.width = 13,
  this.height = 18,
  this.thickness = 1,
  this.color,
}) {
  if (!width.isFinite || width < 0) {
    throw RangeError.value(
      width,
      'width',
      'Must be a finite value greater than or equal to zero.',
    );
  }
  if (!height.isFinite || height < 0) {
    throw RangeError.value(
      height,
      'height',
      'Must be a finite value greater than or equal to zero.',
    );
  }
  if (!thickness.isFinite || thickness <= 0) {
    throw RangeError.value(
      thickness,
      'thickness',
      'Must be a finite value greater than zero.',
    );
  }
}