items property
Ordered status bar item list.
Items are grouped into start, center, and end placement zones while preserving their list order inside each zone.
Implementation
final List<FdcGridItem> items;
Ordered status bar item list.
Items are grouped into start, center, and end placement zones while preserving their list order inside each zone.
final List<FdcGridItem> items;