backgroundColor property
Background color used by the grid status bar.
When omitted, the grid resolves this to the header background color so the footer visually belongs to the same shell as the header.
Implementation
final Color? backgroundColor;
Background color used by the grid status bar.
When omitted, the grid resolves this to the header background color so the footer visually belongs to the same shell as the header.
final Color? backgroundColor;