backgroundColor property

Color? backgroundColor
final

Background color used for the grid viewport surface, including the empty body area below the last rendered data row.

Implementation

final Color? backgroundColor;