cellTextStyle property
Default text style used by grid cells.
Column-level cell text styles are merged over this style.
Implementation
final TextStyle? cellTextStyle;
Default text style used by grid cells.
Column-level cell text styles are merged over this style.
final TextStyle? cellTextStyle;