rowIndicatorBackgroundColor property

Color? rowIndicatorBackgroundColor
final

Background color used by the leading row indicator body region.

When omitted, the row indicator body uses backgroundColor. The row indicator header continues to use the header background color.

Implementation

final Color? rowIndicatorBackgroundColor;