visible property
Controls whether the grid summary component may be rendered.
Defaults to true. The grid still hides the panel automatically when no
visible column has an active summary aggregate.
Implementation
final bool visible;
Controls whether the grid summary component may be rendered.
Defaults to true. The grid still hides the panel automatically when no
visible column has an active summary aggregate.
final bool visible;