backgroundColor property

Color? backgroundColor
final

Background color used by the grid summary row panel.

When omitted, the grid resolves this to the grid viewport background so the summary row reads as part of the data body.

Implementation

final Color? backgroundColor;