height property
Fixed height of the summary row panel.
When omitted, the grid uses the configured grid row height.
Implementation
final double? height;
Fixed height of the summary row panel.
When omitted, the grid uses the configured grid row height.
final double? height;