showTopSeparator property
Whether the summary row draws a top separator between the grid viewport and the summary row.
Implementation
final bool? showTopSeparator;
Whether the summary row draws a top separator between the grid viewport and the summary row.
final bool? showTopSeparator;