verticalSeparatorInset property

double? verticalSeparatorInset
final

Symmetric inset used above and below vertical summary cell separators.

Defaults to the same inset used by header column separators. Set to zero to render full-height summary separators.

Implementation

final double? verticalSeparatorInset;