style property
Legacy root-grid style override kept for compatibility with the original narrow FdcGridTheme API.
Implementation
final FdcGridStyle? style;
Legacy root-grid style override kept for compatibility with the original narrow FdcGridTheme API.
final FdcGridStyle? style;