cellErrorIndicator property
Validation marker styling used for cells with field errors.
Implementation
final FdcErrorIndicatorMarkerStyle cellErrorIndicator;
Validation marker styling used for cells with field errors.
final FdcErrorIndicatorMarkerStyle cellErrorIndicator;