light constant
FdcGridThemeData
const light
Soft neutral light grid theme with a subtle grey application-surface look.
Implementation
static const FdcGridThemeData light = fdcGridLightTheme;
Soft neutral light grid theme with a subtle grey application-surface look.
static const FdcGridThemeData light = fdcGridLightTheme;