visible property
Controls whether the toolbar component is rendered.
The default is true, so a grid renders the built-in toolbar search without requiring explicit toolbar configuration.
Implementation
final bool visible;
Controls whether the toolbar component is rendered.
The default is true, so a grid renders the built-in toolbar search without requiring explicit toolbar configuration.
final bool visible;