backgroundColor property
Background color used by the grid toolbar.
When omitted, the grid resolves this to the header background color so the toolbar visually belongs to the same grid shell.
Implementation
final Color? backgroundColor;
Background color used by the grid toolbar.
When omitted, the grid resolves this to the header background color so the toolbar visually belongs to the same grid shell.
final Color? backgroundColor;