FdcGridTranslations class
Grid text resources.
Constructors
- FdcGridTranslations({String filters = 'Filters', String showFilters = 'Show filters', String hideFilters = 'Hide filters', String clearFilter = 'Clear filter', String clearFilters = 'Clear filters', String clearAllFilters = 'Clear all filters', String sorting = 'Sorting', String sortAscending = 'Sort ascending', String sortDescending = 'Sort descending', String addAscendingSort = 'Add ascending sort', String addDescendingSort = 'Add descending sort', String clearSort = 'Clear sort', String clearAllSorts = 'Clear all sorts', String columnPinning = 'Column pinning', String pinLeft = 'Pin to left', String pinRight = 'Pin to right', String unpin = 'Unpin', String unpinAllColumns = 'Unpin all columns', String resetGridLayout = 'Reset grid layout', String noActionsAvailable = 'No actions available', String mainMenu = 'Main menu', String export = 'Export', String exportTo(String formatLabel)?, String page = 'Page', String of = 'of', String noRangeFilter = 'No range filter', String rangeFrom = 'From', String rangeTo = 'To', String searchHint = 'Search...', String clearSearch = 'Clear search', String caseSensitiveSearchOn = 'Case sensitive search is on', String caseSensitiveSearchOff = 'Case sensitive search is off', String searchOptions = 'Search options', String searchAnyWord = 'Any word', String searchAllWords = 'All words', String searchExactPhrase = 'Exact phrase', String firstPage = 'First page', String previousPage = 'Previous page', String nextPage = 'Next page', String lastPage = 'Last page', String selected(int count)?, String valueOf(String value, String maximum)?, String rating = 'Rating', String trendNoData = 'Trend: No data', String trend(String formatLabel)?, String browse = 'Browse', String edit = 'Edit', String insert = 'Insert', String closed = 'Closed', String loading = 'Loading', String applyingUpdates = 'Applying updates', String openingDataset = 'Opening dataset', String loadingDataset = 'Loading dataset', String filteringDataset = 'Filtering dataset', String searchingDataset = 'Searching dataset', String sortingDataset = 'Sorting dataset', String datasetWork = 'Dataset work', String aggregateSum = 'Sum', String aggregateMin = 'Min', String aggregateMax = 'Max', String aggregateAvg = 'Avg', String state = 'State', String filtered = 'Filtered', String sorted = 'Sorted', String noRecords = '0 records', String record(int recordNumber, int? totalCount)?, String showSelectedRows = 'Show selected rows', String showUnselectedRows = 'Show unselected rows', String clearSelectionFilter = 'Clear selection filter', String containsPhrase = 'Contains phrase', String startsWith = 'Starts with', FdcFilterOperatorTranslations operatorLabels = const FdcFilterOperatorTranslations()})
-
Creates grid translations.
const
Properties
- addAscendingSort → String
-
Add ascending sort action text for multi-column sort chains.
final
- addDescendingSort → String
-
Add descending sort action text for multi-column sort chains.
final
- aggregateAvg → String
-
Average aggregate label used in summary rows and menus.
final
- aggregateMax → String
-
Maximum aggregate label used in summary rows and menus.
final
- aggregateMin → String
-
Minimum aggregate label used in summary rows and menus.
final
- aggregateSum → String
-
Sum aggregate label used in summary rows and menus.
final
- applyingUpdates → String
-
Applying-updates dataset state text.
final
- browse → String
-
Browse row-state tooltip text.
final
- caseSensitiveSearchOff → String
-
Case-sensitive search disabled tooltip text.
final
- caseSensitiveSearchOn → String
-
Case-sensitive search enabled tooltip text.
final
- clearAllFilters → String
-
Clear all filters action text from a column filter section.
final
- clearAllSorts → String
-
Clear all sort entries action text.
final
- clearFilter → String
-
Clear current filter action text.
final
- clearFilters → String
-
Clear all column filters from the main grid menu.
final
- clearSearch → String
-
Clear toolbar search action text.
final
- clearSelectionFilter → String
-
Clears row selection filter text.
final
- clearSort → String
-
Clear sort action text.
final
- closed → String
-
Closed dataset state text.
final
- columnPinning → String
-
Column pinning group label.
final
- containsPhrase → String
-
Global search mode label for contains-phrase search.
final
- datasetWork → String
-
Generic dataset work semantics text.
final
- edit → String
-
Edit row-state tooltip text.
final
- export → String
-
Toolbar/export menu tooltip text.
final
- filtered → String
-
Active filter status text.
final
- filteringDataset → String
-
Dataset filter work semantics text.
final
- filters → String
-
Header filter group label.
final
- firstPage → String
-
First page action tooltip text.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideFilters → String
-
Hide filters menu action text.
final
- insert → String
-
Insert row-state tooltip text.
final
- lastPage → String
-
Last page action tooltip text.
final
- loading → String
-
Loading dataset state text.
final
- loadingDataset → String
-
Dataset load work semantics text.
final
- mainMenu → String
-
Toolbar/main-menu tooltip text.
final
- nextPage → String
-
Next page action tooltip text.
final
- noActionsAvailable → String
-
Empty menu state text.
final
- noRangeFilter → String
-
Range filter empty-state text.
final
- noRecords → String
-
Empty record-count status text.
final
- of → String
-
Count relation label.
final
- openingDataset → String
-
Dataset open work semantics text.
final
- operatorLabels → FdcFilterOperatorTranslations
-
Filter operator labels.
final
- page → String
-
Page label.
final
- pinLeft → String
-
Pin left action text.
final
- pinRight → String
-
Pin right action text.
final
- previousPage → String
-
Previous page action tooltip text.
final
- rangeFrom → String
-
Range filter from-field label.
final
- rangeTo → String
-
Range filter to-field label.
final
- rating → String
-
Rating semantics label.
final
- resetGridLayout → String
-
Reset grid layout action text.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchAllWords → String
-
Search match-mode label for all words.
final
- searchAnyWord → String
-
Search match-mode label for any word.
final
- searchExactPhrase → String
-
Search match-mode label for exact phrase.
final
- searchHint → String
-
Toolbar search field hint text.
final
- searchingDataset → String
-
Dataset search work semantics text.
final
- searchOptions → String
-
Search options menu tooltip text.
final
- showFilters → String
-
Show filters menu action text.
final
- showSelectedRows → String
-
Row selection filter text for selected rows.
final
- showUnselectedRows → String
-
Row selection filter text for unselected rows.
final
- sortAscending → String
-
Sort ascending action text.
final
- sortDescending → String
-
Sort descending action text.
final
- sorted → String
-
Active sort status text.
final
- sorting → String
-
Sorting group label.
final
- sortingDataset → String
-
Dataset sort work semantics text.
final
- startsWith → String
-
Global search mode label for starts-with search.
final
- state → String
-
Dataset state status-bar label.
final
- trendNoData → String
-
Sparkline empty semantics label.
final
- unpin → String
-
Unpin action text.
final
- unpinAllColumns → String
-
Unpin all user-pinned columns action text.
final
Methods
-
aggregateLabel(
FdcAggregate aggregate) → String - Resolves a localized label for a summary aggregate.
-
exportTo(
String formatLabel) → String - Formats a toolbar export menu action label.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
record(
int recordNumber, int? totalCount) → String - Formats the current record status text.
-
selected(
int count) → String - Formats a selected item count.
-
toString(
) → String -
A string representation of this object.
inherited
-
trend(
String points) → String - Formats a sparkline trend semantics label.
-
valueOf(
String value, String maximum) → String - Formats a value-of-maximum label.
-
workPhaseLabel(
String phaseName) → String - Resolves a localized label for a dataset work phase.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited