FdcGridVerticalScrollMode enum

Defines the available grid vertical scroll mode values.

Inheritance
Available extensions

Values

smooth → const FdcGridVerticalScrollMode

Pixel-based scrolling. The grid does not snap to row boundaries and scrolling does not change the current dataset record.

recordScroll → const FdcGridVerticalScrollMode

Record-oriented scrolling. Vertical scrolling snaps to row boundaries and the first visible row becomes the current dataset record.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FdcGridVerticalScrollMode>
A constant List of the values in this enum, in order of their declaration.