onLookup property
Optional asynchronous lookup invoked by the lookup button or shortcut.
Implementation
final FdcEditorLookup<int>? onLookup;
Optional asynchronous lookup invoked by the lookup button or shortcut.
final FdcEditorLookup<int>? onLookup;