FdcKeyboardKey enum
Keyboard keys supported by FdcKeyboardShortcut.
Values
- f1 → const FdcKeyboardKey
-
F1 option.
- f2 → const FdcKeyboardKey
-
F2 option.
- f3 → const FdcKeyboardKey
-
F3 option.
- f4 → const FdcKeyboardKey
-
F4 option.
- f5 → const FdcKeyboardKey
-
F5 option.
- f6 → const FdcKeyboardKey
-
F6 option.
- f7 → const FdcKeyboardKey
-
F7 option.
- f8 → const FdcKeyboardKey
-
F8 option.
- f9 → const FdcKeyboardKey
-
F9 option.
- f10 → const FdcKeyboardKey
-
F10 option.
- f11 → const FdcKeyboardKey
-
F11 option.
- f12 → const FdcKeyboardKey
-
F12 option.
- enter → const FdcKeyboardKey
-
Enter option.
- space → const FdcKeyboardKey
-
Space option.
- escape → const FdcKeyboardKey
-
Escape option.
- tab → const FdcKeyboardKey
-
Tab option.
- arrowUp → const FdcKeyboardKey
-
Arrow up option.
- arrowDown → const FdcKeyboardKey
-
Arrow down option.
- arrowLeft → const FdcKeyboardKey
-
Arrow left option.
- arrowRight → const FdcKeyboardKey
-
Arrow right option.
- home → const FdcKeyboardKey
-
Home option.
- end → const FdcKeyboardKey
-
End option.
- pageUp → const FdcKeyboardKey
-
Page up option.
- pageDown → const FdcKeyboardKey
-
Page down option.
- insert → const FdcKeyboardKey
-
Insert option.
- delete → const FdcKeyboardKey
-
Delete option.
- backspace → const FdcKeyboardKey
-
Backspace option.
- digit0 → const FdcKeyboardKey
-
Digit0 option.
- digit1 → const FdcKeyboardKey
-
Digit1 option.
- digit2 → const FdcKeyboardKey
-
Digit2 option.
- digit3 → const FdcKeyboardKey
-
Digit3 option.
- digit4 → const FdcKeyboardKey
-
Digit4 option.
- digit5 → const FdcKeyboardKey
-
Digit5 option.
- digit6 → const FdcKeyboardKey
-
Digit6 option.
- digit7 → const FdcKeyboardKey
-
Digit7 option.
- digit8 → const FdcKeyboardKey
-
Digit8 option.
- digit9 → const FdcKeyboardKey
-
Digit9 option.
- keyA → const FdcKeyboardKey
-
Key a option.
- keyB → const FdcKeyboardKey
-
Key b option.
- keyC → const FdcKeyboardKey
-
Key c option.
- keyD → const FdcKeyboardKey
-
Key d option.
- keyE → const FdcKeyboardKey
-
Key e option.
- keyF → const FdcKeyboardKey
-
Key f option.
- keyG → const FdcKeyboardKey
-
Key g option.
- keyH → const FdcKeyboardKey
-
Key h option.
- keyI → const FdcKeyboardKey
-
Key i option.
- keyJ → const FdcKeyboardKey
-
Key j option.
- keyK → const FdcKeyboardKey
-
Key k option.
- keyL → const FdcKeyboardKey
-
Key l option.
- keyM → const FdcKeyboardKey
-
Key m option.
- keyN → const FdcKeyboardKey
-
Key n option.
- keyO → const FdcKeyboardKey
-
Key o option.
- keyP → const FdcKeyboardKey
-
Key p option.
- keyQ → const FdcKeyboardKey
-
Key q option.
- keyR → const FdcKeyboardKey
-
Key r option.
- keyS → const FdcKeyboardKey
-
Key s option.
- keyT → const FdcKeyboardKey
-
Key t option.
- keyU → const FdcKeyboardKey
-
Key u option.
- keyV → const FdcKeyboardKey
-
Key v option.
- keyW → const FdcKeyboardKey
-
Key w option.
- keyX → const FdcKeyboardKey
-
Key x option.
- keyY → const FdcKeyboardKey
-
Key y option.
- keyZ → const FdcKeyboardKey
-
Key z option.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FdcKeyboardKey> - A constant List of the values in this enum, in order of their declaration.