isSupported method
Whether resources for the given locale can be loaded by this delegate.
Return true if the instance of T loaded by this delegate's load
method supports the given locale's language.
Implementation
@override
bool isSupported(Locale locale) {
switch (locale.languageCode.toLowerCase()) {
case 'en':
case 'hr':
case 'it':
case 'de':
case 'fr':
case 'es':
return true;
}
return false;
}