lookupText property

String? lookupText
final

Text used as lookup input.

When a lookup is invoked from an active editor this is the current raw editor text, including an empty string when the user cleared the editor. When interactive search is invoked without an active editor this is the current field contents formatted as text, or null when the field value itself is null/not textually available.

Implementation

final String? lookupText;