FdcLookupResult class

Result returned by grid and standalone editor lookup callbacks.

Returning null from a lookup callback cancels the lookup. Returning an FdcLookupResult applies the supplied dataset field values as one logical lookup write set.

Annotations

Constructors

FdcLookupResult(Map<String, Object?> values)
Creates a FdcLookupResult.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Map<String, Object?>
Dataset field values to write when the lookup is accepted.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited