values property

Map<String, Object?> values
final

Dataset field values to write when the lookup is accepted.

Keys are dataset field names. Values may include the field that invoked the lookup and any same-record sibling fields that should be updated by the lookup workflow.

Implementation

final Map<String, Object?> values;