FdcMenuOverlay class

Controls transient menus created by FD Components.

Host applications can call dismissAll when an interaction happens outside Flutter's pointer event boundary, such as a click in a parent page around an embedded Flutter Web iframe.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dismissAll() → void
Closes every currently mounted FD Components menu anchor.