FdcMenuTitle class

A non-interactive caption used to label a group of menu entries.

Inheritance

Constructors

FdcMenuTitle({required String text})
Creates a FdcMenuTitle.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
Text displayed to the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited