FdcMenuWidgetEntry class
A menu entry that renders arbitrary child content without action semantics.
- Inheritance
-
- Object
- FdcMenuEntry
- FdcMenuWidgetEntry
Constructors
- FdcMenuWidgetEntry({required Widget child})
-
Creates a FdcMenuWidgetEntry.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited