FdcOption<T> class

Static value used by combo-like controls and filters.

Constructors

FdcOption({required T value, required String label})
Creates a FdcOption.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
label String
Display label shown to the user.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
Current value carried by this object.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override