FdcPageRefreshMode enum
Controls which page is opened by FdcDataSet.paging.refreshPage.
keepPage reloads the current page index. It does not attempt to relocate the current record if backend changes moved that record to another page. firstPage reloads from page zero.
Values
- keepPage → const FdcPageRefreshMode
-
Reloads the current page index.
- firstPage → const FdcPageRefreshMode
-
Reloads from page zero.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FdcPageRefreshMode> - A constant List of the values in this enum, in order of their declaration.