width property
Optional fixed width. When omitted, the bar expands to parent constraints once a dataset work state is available.
Implementation
final double? width;
Optional fixed width. When omitted, the bar expands to parent constraints once a dataset work state is available.
final double? width;