reserveSpaceWhenIdle property
Whether the widget should keep its configured footprint while the dataset is idle or while a work operation is waiting for visibilityDelay.
This is useful in compact shell surfaces such as grid status bars where the text should not shift horizontally when dataset work starts or ends.
Implementation
final bool? reserveSpaceWhenIdle;