progressTextBuilder property
Optional callback that derives display text from the progress value.
Implementation
final FdcProgressTextBuilder? progressTextBuilder;
Optional callback that derives display text from the progress value.
final FdcProgressTextBuilder? progressTextBuilder;