FdcProgressValue class
Value object for progress editors when styling varies per row.
Constructors
- FdcProgressValue(num value, {String? text, Color? color, Color? backgroundColor})
-
Creates a FdcProgressValue.
const
Properties
- backgroundColor → Color?
-
Optional background color override for this value.
final
- color → Color?
-
Optional foreground color associated with this value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
Text displayed to the user.
final
- value → num
-
Current value carried by this object.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited