onPressed property
Custom command executed when this action is pressed.
Built-in actions leave this null and use their predefined behavior.
Implementation
final FdcRowActionCallback? onPressed;
Custom command executed when this action is pressed.
Built-in actions leave this null and use their predefined behavior.
final FdcRowActionCallback? onPressed;