sortBy method
Adds fieldName as the next sort priority and returns its direction step.
Implementation
@useResult
FdcSortOrderStep sortBy(String fieldName) {
return FdcSortOrderStep._(this, fieldName);
}
Adds fieldName as the next sort priority and returns its direction step.
@useResult
FdcSortOrderStep sortBy(String fieldName) {
return FdcSortOrderStep._(this, fieldName);
}