FdcSummaryLabelAlignment enum

Layout of an optional summary label inside its summary cell.

inline keeps the label in the same text flow as the summary value. startAligned pins the label to the logical start edge of the summary cell and keeps the summary value aligned by the cell's normal summary alignment.

Inheritance
Available extensions

Values

inline → const FdcSummaryLabelAlignment

Render the label inline with the summary value.

startAligned → const FdcSummaryLabelAlignment

Render the label at the logical start edge of the summary cell.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FdcSummaryLabelAlignment>
A constant List of the values in this enum, in order of their declaration.