onLookup property
Optional asynchronous lookup invoked by the lookup button or shortcut.
Implementation
final FdcEditorLookup<Object?>? onLookup;
Optional asynchronous lookup invoked by the lookup button or shortcut.
final FdcEditorLookup<Object?>? onLookup;