FdcTranslations class
User-facing FDC text resources.
The object is intentionally typed instead of map-based so component code and application overrides remain discoverable, refactor-safe and testable.
Constructors
- FdcTranslations({FdcCommonTranslations common = const FdcCommonTranslations(), FdcDialogTranslations dialogs = const FdcDialogTranslations(), FdcGridTranslations grid = const FdcGridTranslations(), FdcValidationTranslations validation = const FdcValidationTranslations()})
-
Creates a custom FDC translation set.
const
- FdcTranslations.deDe()
-
German (Germany) FDC translations.
factory
- FdcTranslations.enUs()
-
English (United States) FDC translations.
factory
- FdcTranslations.esEs()
-
Spanish (Spain) FDC translations.
factory
- FdcTranslations.frFr()
-
French (France) FDC translations.
factory
- FdcTranslations.hrHr()
-
Croatian (Croatia) FDC translations.
factory
- FdcTranslations.itIt()
-
Italian (Italy) FDC translations.
factory
Properties
- common → FdcCommonTranslations
-
Common component text resources.
final
- dialogs → FdcDialogTranslations
-
Dialog text resources.
final
- grid → FdcGridTranslations
-
Grid text resources.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validation → FdcValidationTranslations
-
Validation text resources.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited