maxValue constant
String
const maxValue
Emitted when a numeric field value is above its configured maximum.
Implementation
static const String maxValue = 'maxValue';
Emitted when a numeric field value is above its configured maximum.
static const String maxValue = 'maxValue';