FdcValidationError class

Structured validation failure for a field or whole record.

fieldName is null for record-level validation errors.

Constructors

FdcValidationError({required String message, String? fieldName, int? recordId, String? code})
Creates a FdcValidationError.
const

Properties

code String?
Optional stable machine-readable validation code.
final
fieldName String?
Dataset field name associated with this object.
final
hashCode int
The hash code for this object.
no setterinherited
message String
User-facing message text.
final
recordId int?
Internal record identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited