exportStyleOf static method
Returns the export style configured for the nearest FdcApp.
Implementation
static FdcExportStyle exportStyleOf(BuildContext context) {
return _scopeOf(context)?.exportStyle ?? const FdcExportStyle();
}
Returns the export style configured for the nearest FdcApp.
static FdcExportStyle exportStyleOf(BuildContext context) {
return _scopeOf(context)?.exportStyle ?? const FdcExportStyle();
}