formatSettings property
Explicit format settings for descendant FDC controls.
When null, settings are resolved from the active locale through formatResolver.
Implementation
final FdcFormatSettings? formatSettings;
Explicit format settings for descendant FDC controls.
When null, settings are resolved from the active locale through formatResolver.
final FdcFormatSettings? formatSettings;