formatsOf static method

FdcFormatSettings formatsOf(
  1. BuildContext context
)

Resolves the effective format settings for this build context.

An explicit formatSettings value wins. Otherwise the active locale is resolved through the nearest formatResolver or the default resolver.

Implementation

static FdcFormatSettings formatsOf(BuildContext context) {
  final explicit = _scopeOf(context)?.formatSettings;
  return explicit?.resolveLocaleOnlyPreset() ?? _formatsFromContext(context);
}