expandDetailRow static method
Expands a detail row through the attached grid runtime.
Implementation
static bool expandDetailRow(FdcGridController controller, {int? rowIndex}) {
return controller._expandDetailRowCommand(rowIndex: rowIndex);
}
Expands a detail row through the attached grid runtime.
static bool expandDetailRow(FdcGridController controller, {int? rowIndex}) {
return controller._expandDetailRowCommand(rowIndex: rowIndex);
}