loadLayout static method
Loads a persisted layout, returning whether one was restored.
Implementation
static Future<bool> loadLayout(FdcGridController controller) {
return controller._loadLayout();
}
Loads a persisted layout, returning whether one was restored.
static Future<bool> loadLayout(FdcGridController controller) {
return controller._loadLayout();
}