saveLayout static method
Saves the controller layout through the configured persistence layer.
Implementation
static Future<void> saveLayout(FdcGridController controller) {
return controller._saveLayout();
}
Saves the controller layout through the configured persistence layer.
static Future<void> saveLayout(FdcGridController controller) {
return controller._saveLayout();
}