layoutChanged abstract method
void
layoutChanged()
Notifies the feature that the current grid layout has changed.
Implementation
void layoutChanged();
Notifies the feature that the current grid layout has changed.
void layoutChanged();