canExpand abstract method
Returns whether the row described by context may be expanded.
Implementation
bool canExpand(FdcGridDetailRowContext context);
Returns whether the row described by context may be expanded.
bool canExpand(FdcGridDetailRowContext context);