collapseOnCurrentRowChange property
bool
get
collapseOnCurrentRowChange
Whether changing the dataset current row collapses expanded detail content.
Implementation
bool get collapseOnCurrentRowChange;
Whether changing the dataset current row collapses expanded detail content.
bool get collapseOnCurrentRowChange;