height property
double?
get
height
Fixed detail-row height, or null to size from built content.
Implementation
double? get height;
Fixed detail-row height, or null to size from built content.
double? get height;