header property
Header component configuration.
The header is visible by default. Its height, filter row visibility, filter debounce behavior, and visual style are owned by this component.
Implementation
final FdcGridHeader header;
Header component configuration.
The header is visible by default. Its height, filter row visibility, filter debounce behavior, and visual style are owned by this component.
final FdcGridHeader header;