onCellDoubleTap property
Called when a body cell is double-clicked or double-tapped.
The callback is emitted before the grid starts its built-in edit action.
Implementation
final FdcGridCellPointerEvent? onCellDoubleTap;
Called when a body cell is double-clicked or double-tapped.
The callback is emitted before the grid starts its built-in edit action.
final FdcGridCellPointerEvent? onCellDoubleTap;