toolbar property

FdcGridToolbar toolbar
final

Toolbar component configuration.

The toolbar is visible by default and renders its default search item. Provide a custom FdcGridToolbar.items list for full control over built-in and custom toolbar command ordering, or set FdcGridToolbar.visible to false to hide the shell.

Implementation

final FdcGridToolbar toolbar;