autoLoad property
bool
get
autoLoad
Whether the grid should load a persisted snapshot during initialization.
Implementation
bool get autoLoad;
Whether the grid should load a persisted snapshot during initialization.
bool get autoLoad;