autoSaveDelay property
Duration
get
autoSaveDelay
Debounce interval used before an automatic save is performed.
Implementation
Duration get autoSaveDelay;
Debounce interval used before an automatic save is performed.
Duration get autoSaveDelay;