markSnapshotSaved method
Records that snapshot is the latest successfully persisted layout state.
Implementation
void markSnapshotSaved(FdcGridLayoutSnapshot snapshot) {}
Records that snapshot is the latest successfully persisted layout state.
void markSnapshotSaved(FdcGridLayoutSnapshot snapshot) {}