saveSnapshot abstract method
Persists snapshot.
rethrowError controls whether storage failures propagate to the caller.
Implementation
FutureOr<void> saveSnapshot(
FdcGridLayoutSnapshot snapshot, {
required bool rethrowError,
});
Persists snapshot.
rethrowError controls whether storage failures propagate to the caller.
FutureOr<void> saveSnapshot(
FdcGridLayoutSnapshot snapshot, {
required bool rethrowError,
});