canFillSingleValue abstract method
Resolves whether a single clipboard value can fill the selected range.
Implementation
bool canFillSingleValue(FdcGridRangeSelectionHost host);
Resolves whether a single clipboard value can fill the selected range.
bool canFillSingleValue(FdcGridRangeSelectionHost host);