canShowContextMenu abstract method
Resolves whether the range context menu is currently allowed.
Implementation
bool canShowContextMenu(FdcGridRangeSelectionHost host);
Resolves whether the range context menu is currently allowed.
bool canShowContextMenu(FdcGridRangeSelectionHost host);