enabled property
bool
get
enabled
Whether the feature is enabled by its public configuration.
Implementation
bool get enabled;
Whether the feature is enabled by its public configuration.
bool get enabled;