handleKeyEvent method
Gives the feature first chance to handle grid keyboard input.
Returning null lets default grid key handling continue.
Implementation
KeyEventResult? handleKeyEvent(KeyEvent event) => null;
Gives the feature first chance to handle grid keyboard input.
Returning null lets default grid key handling continue.
KeyEventResult? handleKeyEvent(KeyEvent event) => null;