isAvailable abstract method
Resolves whether the feature is currently available for the attached grid.
Implementation
bool isAvailable(FdcGridRangeSelectionHost host);
Resolves whether the feature is currently available for the attached grid.
bool isAvailable(FdcGridRangeSelectionHost host);