resolveBackgroundColor abstract method
Resolves the optional selected range background color supplied by the feature.
Implementation
Color? resolveBackgroundColor(FdcGridRangeSelectionHost host);
Resolves the optional selected range background color supplied by the feature.
Color? resolveBackgroundColor(FdcGridRangeSelectionHost host);