resolveBorderThickness abstract method
Resolves the range outline thickness supplied by the feature.
Extension implementations must return a positive value.
Implementation
double resolveBorderThickness(FdcGridRangeSelectionHost host);
Resolves the range outline thickness supplied by the feature.
Extension implementations must return a positive value.
double resolveBorderThickness(FdcGridRangeSelectionHost host);