dataSet property

FdcDataSet get dataSet

Dataset attached to the host grid for the lifetime of this host view.

Extension code may inspect public dataset state and values through this reference but must not assume that the dataset current record is the same row as an arbitrary range-selection cell.

Implementation

FdcDataSet get dataSet;