backgroundColor property

Color? backgroundColor
final

Optional fill color requested by the feature for the selected range.

A null value means that the overlay should not paint a selection fill.

Implementation

final Color? backgroundColor;