showSelectionHandle property
Whether the resize handle is painted at the normalized bottom-right corner.
Implementation
final bool showSelectionHandle;
Whether the resize handle is painted at the normalized bottom-right corner.
final bool showSelectionHandle;