pointerDragActive property

bool get pointerDragActive

True while this session owns an active pointer-drag range gesture.

The value is transient input state and must be cleared when the drag ends, is cancelled, or the host resets the session.

Implementation

bool get pointerDragActive;
set pointerDragActive (bool value)

Updates whether this session owns an active pointer-drag gesture.

Implementation

set pointerDragActive(bool value);