updatePointerDrag abstract method
Extends an active pointer drag to target, returning whether state changed.
Implementation
bool updatePointerDrag(FdcGridCellRef target);
Extends an active pointer drag to target, returning whether state changed.
bool updatePointerDrag(FdcGridCellRef target);