updatePointerHoverCell abstract method
Updates the cell currently under the pointer and returns whether state changed.
Implementation
bool updatePointerHoverCell(FdcGridCellRef? next);
Updates the cell currently under the pointer and returns whether state changed.
bool updatePointerHoverCell(FdcGridCellRef? next);