decimalFastTokenValueAt method

FdcDecimal? decimalFastTokenValueAt(
  1. int tokenIndex
)

Returns the compiled decimal fast-path value for the ordered search token.

This mirrors the local dataset search matcher and is used by backend adapters that need to translate the same search semantics to a native query language.

Implementation

FdcDecimal? decimalFastTokenValueAt(int tokenIndex) =>
    _decimalFastTokenValueAt(tokenIndex);