integerFastTokenValueAt method
Returns the compiled integer fast-path value for the ordered search token.
This mirrors the local dataset search matcher and is used by backend adapters that need to translate the same search semantics to a native query language.
Implementation
int? integerFastTokenValueAt(int tokenIndex) =>
_integerFastTokenValueAt(tokenIndex);