FdcBadgeValue class

Value object for badge editors when text, color, icon, or text style varies per row.

Constructors

FdcBadgeValue({required String text, Color? color, IconData? icon, TextStyle? textStyle})
Creates a FdcBadgeValue.
const

Properties

color Color?
Optional foreground color associated with this value.
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
Optional icon shown with the item.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Text displayed to the user.
final
textStyle TextStyle?
Optional text style override for this value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited