FdcBinaryExportPayload class final
Binary payload returned by writers such as PDF or spreadsheet exporters.
- Inheritance
-
- Object
- FdcExportPayload
- FdcBinaryExportPayload
Constructors
-
FdcBinaryExportPayload(List<
int> value) - Creates a FdcBinaryExportPayload.
Properties
- bytes → Uint8List
-
Serialized bytes for this payload.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
Text content, or
nullwhen the payload is binary.no setteroverride - value → Uint8List
-
Binary content carried by this payload.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited