onControlPointerDown property
Internal hook used by custom in-cell mouse controls to preserve the grid viewport while activating/writing the owning cell.
Application code should usually call control instead of this callback.
Implementation
final void Function(Offset globalPosition)? onControlPointerDown;