FdcChangeSet class
Immutable collection of pending dataset insert, update, and delete actions.
Data adapters receive a change set when FdcDataSet.apply() persists pending
edits.
Constructors
-
FdcChangeSet({required List<
FdcChangeSetEntry> inserts, required List<FdcChangeSetEntry> updates, required List<FdcChangeSetEntry> deletes, List<FdcFieldDef> fields = const <FdcFieldDef>[]}) -
Creates a FdcChangeSet.
const
Properties
-
deletes
→ List<
FdcChangeSetEntry> -
Records pending deletion.
final
-
fields
→ List<
FdcFieldDef> -
Dataset schema fields used by persistence adapters.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inserts
→ List<
FdcChangeSetEntry> -
Records pending insertion.
final
- isEmpty → bool
-
Whether this change set contains no inserts, updates, or deletes.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
updates
→ List<
FdcChangeSetEntry> -
Records pending update.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited