FdcCommonTranslations class
Common FDC text shared by multiple component families.
Constructors
- FdcCommonTranslations({String ok = 'OK', String yes = 'Yes', String no = 'No', String cancel = 'Cancel', String apply = 'Apply', String clear = 'Clear', String search = 'Search', String all = 'All', String delete = 'Delete', String close = 'Close', String pickDate = 'Pick date', String lookup = 'Lookup', String noResults = 'No results'})
-
Creates common translations.
const
Properties
- all → String
-
All values label.
final
- apply → String
-
Apply action text.
final
- cancel → String
-
Cancel action text.
final
- clear → String
-
Clear action text.
final
- close → String
-
Close action text.
final
- delete → String
-
Delete action text.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lookup → String
-
Lookup action text.
final
- no → String
-
No action text.
final
- noResults → String
-
Empty search result text.
final
- ok → String
-
OK action text.
final
- pickDate → String
-
Date picker tooltip text.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- search → String
-
Search hint or action text.
final
- yes → String
-
Yes action text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited