FdcDataAdapterCapabilities.none constructor

const FdcDataAdapterCapabilities.none()

Implementation

const FdcDataAdapterCapabilities.none()
  : filtering = false,

    /// Whether the adapter can execute dataset sort descriptors.
    sorting = false,

    /// Whether the adapter can load bounded pages of rows.
    paging = false,

    /// Whether load responses can report the total matching row count.
    totalCount = false,

    /// The search.
    search = false,

    /// Whether the adapter can execute aggregate queries.
    aggregates = false,

    /// Whether key-based selected-row filtering is supported.
    selectedKeyFiltering = false;