FdcDataAggregateResult class
Values returned for an FdcDataAggregateRequest.
Results are keyed by FdcDataAggregateKey so callers can correlate values with requested field/function pairs.
Constructors
-
FdcDataAggregateResult({Map<
FdcDataAggregateKey, Object?> values = const <FdcDataAggregateKey, Object?>{}}) -
Creates a FdcDataAggregateResult.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ Map<
FdcDataAggregateKey, Object?> -
Field values carried by this object.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
valueFor(
String fieldName, FdcAggregate aggregate) → Object? -
Returns the value for the
fieldNameandaggregatepair, ornullwhen the adapter omitted it.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited