internalRowIds property
Optional stable adapter-local row identities.
Memory-style adapters can provide these so datasets without explicit key fields still have a stable internal identity for update/delete matching. These ids are internal and are never exposed as dataset fields.
Implementation
final List<int>? internalRowIds;