FdcDataSetAfterEdit typedef
FdcDataSetAfterEdit =
void Function(FdcDataSet dataSet)
Called after the edit buffer has been created and the dataset entered edit state, before listeners are notified.
Use this as a notification hook; mutations that belong to the edit should use normal field assignment APIs against the active edit buffer.
Implementation
typedef FdcDataSetAfterEdit = void Function(FdcDataSet dataSet);