FdcDataSetBeforeClose typedef
FdcDataSetBeforeClose =
void Function(FdcDataSet dataSet)
Called immediately before a dataset is closed and its current view is cleared.
Throw FdcDataSetAbortException to keep the dataset open and stop the close operation through the normal abort pipeline.
Implementation
typedef FdcDataSetBeforeClose = void Function(FdcDataSet dataSet);