FdcDataSetBeforeEdit typedef
FdcDataSetBeforeEdit =
void Function(FdcDataSet dataSet)
Called before the current record enters edit state and before an edit buffer is created.
Throw FdcDataSetAbortException to veto editing. Application code may inspect the current record here, but should not start a competing dataset operation.
Implementation
typedef FdcDataSetBeforeEdit = void Function(FdcDataSet dataSet);