clear method

Future<bool> clear({
  1. bool clearRetainedVisibleRecords = true,
  2. bool notify = true,
})

Clears public field and selection filters and rebuilds or reloads the view.

Adapter-level default filters and internal query constraints remain in effect.

Implementation

Future<bool> clear({
  bool clearRetainedVisibleRecords = true,
  bool notify = true,
}) {
  return set(
    const <FdcDataSetFilter>[],
    clearRetainedVisibleRecords: clearRetainedVisibleRecords,
    notify: notify,
  );
}