enableSortValueCache property
Whether normalized sort values/ranks should be cached between sorts.
This helps repeated asc/desc toggles and repeated sorting on the same field avoid rebuilding expensive normalized values for large datasets.
Implementation
final bool enableSortValueCache;