FdcDataSetSearchApi class
Dataset-level global search API.
The dataset owns exactly one active global search state. This object is the public entry point for applying and clearing that search state.
Constructors
-
FdcDataSetSearchApi.internal({required FdcDataSetSearchState readState(), required Future<
void> applySearch(String text, {bool caseSensitive, Map<String, FdcFormatSettings> ? fieldFormatSettings, Map<String, FdcSearchFieldTextFormatter> ? fieldTextFormatters, Iterable<String> ? fields, FdcFormatSettings? formatSettings, FdcSearchMode mode}), required Future<void> clearSearch()}) - Creates a FdcDataSetSearchApi.
Properties
- active → bool
-
True when the dataset has an active global search criterion.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether no global search criterion is active.
no setter
- isNotEmpty → bool
-
Whether a global search criterion is active.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → FdcDataSetSearchState
-
Current global dataset search state.
no setter
Methods
-
apply(
String text, {FdcSearchMode mode = FdcSearchMode.phrase, bool caseSensitive = false, Iterable< String> ? fields, Map<String, FdcSearchFieldTextFormatter> ? fieldTextFormatters, Map<String, FdcFormatSettings> ? fieldFormatSettings, FdcFormatSettings? formatSettings}) → Future<void> - Applies a global search to the dataset view.
-
clear(
) → Future< void> - Clears the active global search and restores the unsearched query/view.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited