FdcDataSetSearchState class
Immutable dataset search state.
Constructors
-
FdcDataSetSearchState({String text = '', FdcSearchMode mode = FdcSearchMode.phrase, bool caseSensitive = false, Set<
String> ? fields, Map<String, FdcSearchFieldTextFormatter> ? fieldTextFormatters, Map<String, FdcFormatSettings> ? fieldFormatSettings, FdcFormatSettings formatSettings = const FdcFormatSettings()}) -
Creates a FdcDataSetSearchState.
const
Properties
- caseSensitive → bool
-
Whether text comparisons preserve letter case.
final
-
fieldFormatSettings
→ Map<
String, FdcFormatSettings> ? -
Formatting overrides keyed by participating record field index.
final
-
fields
→ Set<
String> ? -
Field definitions included in this object.
final
-
fieldTextFormatters
→ Map<
String, FdcSearchFieldTextFormatter> ? -
Search text formatters keyed by participating record field index.
final
- formatSettings → FdcFormatSettings
-
Format settings applied to FDC controls.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isActive → bool
-
Whether text contains a non-whitespace search term.
no setter
- mode → FdcSearchMode
-
Search matching strategy used for text.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
Text displayed to the user.
final
Methods
-
normalized(
) → FdcDataSetSearchState - Returns a canonical search state with trimmed text and normalized field keys.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override