FdcDataSetValidationException class
Exception containing one or more dataset validation errors.
Normal editing APIs generally expose validation through dataset errors and callbacks; this exception is useful for explicit validation flows.
- Implemented types
Constructors
-
FdcDataSetValidationException(List<
FdcValidationError> errors) -
Creates a FdcDataSetValidationException.
const
Properties
-
errors
→ List<
FdcValidationError> -
Errors associated with this result.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited