FdcDataSetWorkInfo class

Immutable snapshot for a dataset work lifecycle transition.

Constructors

FdcDataSetWorkInfo({required int id, required FdcDataSetWorkPhase phase, required FdcDataSetWorkMode mode, required DateTime startedAt, String? message, Object? error, StackTrace? stackTrace})
Creates a FdcDataSetWorkInfo.
const

Properties

error Object?
Error captured for an error transition, when available.
final
hashCode int
The hash code for this object.
no setterinherited
id int
Monotonic dataset-local work id.
final
message String?
Optional user-facing or diagnostic work message.
final
mode FdcDataSetWorkMode
Whether FdcDataSetWork.progress is real percentage progress.
final
phase FdcDataSetWorkPhase
High-level work kind.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
Stack trace captured for an error transition, when available.
final
startedAt DateTime
Start timestamp for this work operation.
final

Methods

copyWith({FdcDataSetWorkPhase? phase, FdcDataSetWorkMode? mode, String? message, Object? error, StackTrace? stackTrace}) FdcDataSetWorkInfo
Creates a copy with selected values replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited