FdcDataType enum

Supported logical data types used by data-aware components.

Inheritance
Available extensions

Values

string → const FdcDataType

Text values.

integer → const FdcDataType

Whole-number values.

decimal → const FdcDataType

Exact fixed-point decimal values.

boolean → const FdcDataType

Boolean values.

date → const FdcDataType

Date-only values.

dateTime → const FdcDataType

Combined date-and-time values.

time → const FdcDataType

Time-of-day values.

guid → const FdcDataType

128-bit GUID values.

object → const FdcDataType

Opaque application object values.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FdcDataType>
A constant List of the values in this enum, in order of their declaration.