FdcDebouncePolicy enum
Defines the available debounce policy values.
Values
- disabled → const FdcDebouncePolicy
-
Do not automatically apply text input changes.
Search/filter text is applied only when the input is explicitly submitted, for example with Enter/Search.
- fixed → const FdcDebouncePolicy
-
Always use the configured debounce duration as-is.
- adaptive → const FdcDebouncePolicy
-
Use the configured debounce duration as the base/minimum and let FDC increase the effective delay internally for larger datasets.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FdcDebouncePolicy> - A constant List of the values in this enum, in order of their declaration.