FdcDefaultFormatResolver class

Default FDC format resolver.

It uses the built-in locale registry first and falls back to neutral English-style technical settings when FDC has no preset for the locale.

Implemented types

Constructors

FdcDefaultFormatResolver()
Creates a FdcDefaultFormatResolver.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(Locale locale) FdcFormatSettings
Resolves format settings for locale.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited