FdcEditorControlsStyle class
Visual styling for non-text editor controls such as boolean and combo UI.
Partial styles can be merged over the resolved editor theme.
Constructors
- FdcEditorControlsStyle({Color? iconColor, Color? disabledIconColor, Color? activeIconColor, Color? checkboxFillColor, Color? checkboxCheckColor, Color? checkboxBorderColor, Color? checkboxDisabledFillColor, Color? checkboxDisabledCheckColor, Color? checkboxDisabledBorderColor, Color? switchThumbColor, Color? switchTrackColor, Color? switchDisabledThumbColor, Color? switchDisabledTrackColor, TextStyle? labelStyle, TextStyle? disabledLabelStyle})
-
Creates a FdcEditorControlsStyle.
const
Properties
- activeIconColor → Color?
-
Color of active or selected control icons.
final
- checkboxBorderColor → Color?
-
Border color of enabled checkboxes.
final
- checkboxCheckColor → Color?
-
Checkmark color of enabled checkboxes.
final
- checkboxDisabledBorderColor → Color?
-
Border color of disabled checkboxes.
final
- checkboxDisabledCheckColor → Color?
-
Checkmark color of disabled checkboxes.
final
- checkboxDisabledFillColor → Color?
-
Fill color of disabled checkboxes.
final
- checkboxFillColor → Color?
-
Fill color of enabled checkboxes.
final
- disabledIconColor → Color?
-
Color of disabled control icons.
final
- disabledLabelStyle → TextStyle?
-
Text style for labels of disabled controls.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iconColor → Color?
-
Color of enabled control icons.
final
- labelStyle → TextStyle?
-
Text style for editor labels.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- switchDisabledThumbColor → Color?
-
Thumb color of disabled switches.
final
- switchDisabledTrackColor → Color?
-
Track color of disabled switches.
final
- switchThumbColor → Color?
-
Thumb color of enabled switches.
final
- switchTrackColor → Color?
-
Track color of enabled switches.
final
Methods
-
copyWith(
{Color? iconColor, Color? disabledIconColor, Color? activeIconColor, Color? checkboxFillColor, Color? checkboxCheckColor, Color? checkboxBorderColor, Color? checkboxDisabledFillColor, Color? checkboxDisabledCheckColor, Color? checkboxDisabledBorderColor, Color? switchThumbColor, Color? switchTrackColor, Color? switchDisabledThumbColor, Color? switchDisabledTrackColor, TextStyle? labelStyle, TextStyle? disabledLabelStyle}) → FdcEditorControlsStyle - Creates a copy with selected values replaced.
-
lerp(
FdcEditorControlsStyle other, double t) → FdcEditorControlsStyle -
Linearly interpolates this style toward
otherbyt. -
merge(
FdcEditorControlsStyle? override) → FdcEditorControlsStyle -
Merges non-null properties from
overrideover this style. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- defaults → const FdcEditorControlsStyle
- Fully resolved fallback style used as the base of style merging.