FdcEditorThemes class
Built-in editor theme presets supplied by FDC.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- black → const FdcEditorThemeData
- Near-black preset for maximum-dark editor surfaces.
- dark → const FdcEditorThemeData
- Dark preset for dark application surfaces.
- light → const FdcEditorThemeData
- Light preset for standard Material surfaces.
- white → const FdcEditorThemeData
- High-contrast white preset with neutral surface chrome.