FdcEditorType enum

Supported visual editor modes.

Inheritance
Available extensions

Values

text → const FdcEditorType

Text option.

integer → const FdcEditorType

Integer option.

decimal → const FdcEditorType

Decimal option.

checkbox → const FdcEditorType

Checkbox option.

switcher → const FdcEditorType

Switcher option.

date → const FdcEditorType

Date option.

dateTime → const FdcEditorType

Date time option.

time → const FdcEditorType

Time option.

memo → const FdcEditorType

Memo option.

combo → const FdcEditorType

Combo option.

badge → const FdcEditorType

Badge option.

progress → const FdcEditorType

Progress option.

custom → const FdcEditorType

Custom option.

action → const FdcEditorType

Action option.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FdcEditorType>
A constant List of the values in this enum, in order of their declaration.