valueFormatter property
Optional display formatter supplied by a presentation source such as a grid.
Raw/object-oriented writers may continue to use the original value. Presentation writers such as PDF can use this formatter to preserve the exact FDC format settings and column display affixes.
Implementation
final FdcExportValueFormatter? valueFormatter;