FdcExportFormatStyle class abstract
Base type for format-specific visual export styles.
Styles are presentation defaults, distinct from writer-specific options, which control writer behavior and format-specific serialization settings.
Constructors
- FdcExportFormatStyle()
-
Creates a FdcExportFormatStyle.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited