FdcExportStyle class final

App- or subtree-level default styles resolved by export writers.

Explicit per-export styles always take precedence over these defaults.

Constructors

FdcExportStyle({FdcExportFormatStyle? pdf, Map<FdcExportFormat, FdcExportFormatStyle> formats = const <FdcExportFormat, FdcExportFormatStyle>{}})
Creates a FdcExportStyle.
const

Properties

formats Map<FdcExportFormat, FdcExportFormatStyle>
Default styles keyed by custom or additional export formats.
final
hashCode int
The hash code for this object.
no setteroverride
pdf FdcExportFormatStyle?
Default style for writers whose format id is pdf.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
styleFor<T extends FdcExportFormatStyle>(FdcExportFormat format) → T?
Returns the style registered for format, when it matches T.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override