FdcExportWriter class abstract interface

Contract implemented by built-in and extension export format writers.

Writers receive fully resolved columns and rows through FdcExportWriterContext and return either text or binary payload content.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(FdcExportWriterContext context) FutureOr<FdcExportPayload>
Serializes context into an export payload.

Operators

operator ==(Object other) bool
The equality operator.
inherited