FdcExporter class

Coordinates FDC exports by resolving rows, columns and format writers.

Use exportDataSet for dataset-aware row scopes or exportRows when a grid or custom source has already materialized the exact row and column shape to export.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

exportDataSet(FdcDataSet dataSet, {required FdcExportFormat format, FdcExportOptions? options, FdcExportWriter? writer, String? suggestedFileName, FdcExportWriterOptions? writerOptions, FdcExportStyle exportStyle = const FdcExportStyle()}) Future<FdcExportResult>
Exports rows from dataSet using the requested format.
exportRows({required FdcExportFormat format, required List<FdcExportColumn> columns, required Iterable<Map<String, Object?>> rows, FdcExportOptions? options, FdcExportWriter? writer, String? suggestedFileName, FdcExportWriterOptions? writerOptions, FdcExportStyle exportStyle = const FdcExportStyle()}) Future<FdcExportResult>
Exports already resolved rows and columns using format.