valueOf<V> method

V? valueOf<V>(
  1. String fieldName
)

Reads another field value from the same visual row.

This is a strict typed accessor: it casts the resolved value to V? and throws a TypeError when the value is not assignable to V. Use tryValueOf when a type mismatch should be treated as a missing value.

Implementation

V? valueOf<V>(String fieldName) {
  _requireField(fieldName, 'FdcFieldContext.valueOf');
  return _fieldValueResolver(fieldName) as V?;
}