isCalculated property
bool
get
isCalculated
True when the field value is derived by calculatedValue.
Calculated fields are recomputed from row data and are read-only to normal dataset writes. They are non-persistent by default unless persistent explicitly overrides that default.
Implementation
bool get isCalculated => calculatedValue != null;