isUpdateable property
bool
get
isUpdateable
True when adapter persistence may write this field during updates.
Generated fields are never updateable even when updateable is true.
This flag controls persistence writes and does not by itself enable or
disable an editing widget.
Implementation
bool get isUpdateable => updateable && !generated;