FdcFilterBuilder class

Fluent AND-only builder for dataset filters.

Use FdcDataSet.filter.where to create it:

await dataSet.filter
  .where('name').contains('ana')
  .and('amount').greaterThan(100)
  .apply();

Properties

context FdcDataSetFilterContext
Non-field filter context currently built by this fluent builder.
no setter
fieldItems List<FdcDataSetFilter>
Field-level filter descriptors currently built by this fluent builder.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedFilter bool?
Built row-selection-state filter, or null when no selection filter is part of the builder.
no setter
sortItems List<FdcDataSetSort>
Returns the current sort items.
no setter

Methods

and(String fieldName) FdcFilterConditionBuilder
Adds another AND condition for fieldName.
apply() Future<bool>
Applies pending changes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
orderBy(String fieldName) FdcFilterOrderStep
Adds fieldName as the next ordering priority.
selected(bool value) FdcFilterBuilder
Adds a row-selection-state filter to the dataset query.
toString() String
A string representation of this object.
inherited
where(String fieldName) FdcFilterConditionBuilder
Starts a condition for fieldName.

Operators

operator ==(Object other) bool
The equality operator.
inherited