FdcFilterEditor enum

Built-in header filter editor modes.

search and combo are the currently polished modes. list and checkbox are intentionally available as lightweight configurable modes so the header filter layer can evolve without changing the public config shape again.

Inheritance
Available extensions

Values

Free text search input.

combo → const FdcFilterEditor

Combo-box filter input.

list → const FdcFilterEditor

List based filter input.

range → const FdcFilterEditor

Two-ended range filter input.

checkbox → const FdcFilterEditor

Boolean checkbox filter input.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FdcFilterEditor>
A constant List of the values in this enum, in order of their declaration.