FdcFilterOperator enum
Supported filter operators used by data-aware components.
Values
- contains → const FdcFilterOperator
-
Text contains the comparison value.
- notContains → const FdcFilterOperator
-
Text does not contain the comparison value.
- equals → const FdcFilterOperator
-
Value equals the comparison value.
- notEquals → const FdcFilterOperator
-
Value does not equal the comparison value.
- startsWith → const FdcFilterOperator
-
Text starts with the comparison value.
- endsWith → const FdcFilterOperator
-
Text ends with the comparison value.
- greaterThan → const FdcFilterOperator
-
Value is greater than the comparison value.
- greaterThanOrEqual → const FdcFilterOperator
-
Value is greater than or equal to the comparison value.
- lessThan → const FdcFilterOperator
-
Value is less than the comparison value.
- lessThanOrEqual → const FdcFilterOperator
-
Value is less than or equal to the comparison value.
- between → const FdcFilterOperator
-
Value lies between the lower and upper bounds.
- inList → const FdcFilterOperator
-
Value occurs in the supplied value list.
- notInList → const FdcFilterOperator
-
Value does not occur in the supplied value list.
- isNull → const FdcFilterOperator
-
Value is null.
- isNotNull → const FdcFilterOperator
-
Value is not null.
- isEmpty → const FdcFilterOperator
-
Value is an empty string or empty supported value.
- isNotEmpty → const FdcFilterOperator
-
Value is not empty.
- isNullOrWhitespace → const FdcFilterOperator
-
Value is null, empty, or whitespace-only text.
- isNotNullOrWhitespace → const FdcFilterOperator
-
Value contains non-whitespace content.
- isTrue → const FdcFilterOperator
-
Boolean value is true.
- isFalse → const FdcFilterOperator
-
Boolean value is false.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FdcFilterOperator> - A constant List of the values in this enum, in order of their declaration.