FdcFilterOperatorTranslations class
Header filter operator text resources.
Constructors
- FdcFilterOperatorTranslations({String contains = 'Contains', String notContains = 'Does not contain', String equals = 'Equals', String notEquals = 'Not equal', String startsWith = 'Starts with', String endsWith = 'Ends with', String greaterThan = 'Greater than', String greaterThanOrEqual = 'Greater than or equal', String lessThan = 'Less than', String lessThanOrEqual = 'Less than or equal', String between = 'Between', String inList = 'In list', String notInList = 'Not in list', String isNull = 'Is null', String isNotNull = 'Is not null', String isEmpty = 'Is empty', String isNotEmpty = 'Is not empty', String isNullOrWhitespace = 'Is null or whitespace', String isNotNullOrWhitespace = 'Is not null or whitespace', String isTrue = 'Is true', String isFalse = 'Is false'})
-
Creates filter operator translations.
const
Properties
- between → String
-
Between operator label.
final
- contains → String
-
Contains operator label.
final
- endsWith → String
-
Ends with operator label.
final
- equals → String
-
Equals operator label.
final
- greaterThan → String
-
Greater-than operator label.
final
- greaterThanOrEqual → String
-
Greater-than-or-equal operator label.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inList → String
-
In-list operator label.
final
- isEmpty → String
-
Is-empty operator label.
final
- isFalse → String
-
Is-false operator label.
final
- isNotEmpty → String
-
Is-not-empty operator label.
final
- isNotNull → String
-
Is-not-null operator label.
final
- isNotNullOrWhitespace → String
-
Not-null-or-whitespace operator label.
final
- isNull → String
-
Is-null operator label.
final
- isNullOrWhitespace → String
-
Null-or-whitespace operator label.
final
- isTrue → String
-
Is-true operator label.
final
- lessThan → String
-
Less-than operator label.
final
- lessThanOrEqual → String
-
Less-than-or-equal operator label.
final
- notContains → String
-
Not contains operator label.
final
- notEquals → String
-
Not equals operator label.
final
- notInList → String
-
Not-in-list operator label.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startsWith → String
-
Starts with operator label.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited