FdcFocusOptions class
App/subtree-level focus behavior defaults for Flutter Data Components.
FdcApp.focus is the preferred place to configure suite-level focus
behavior. Use FdcFocusScope for a local form/panel override.
Constructors
- FdcFocusOptions({bool wrapTraversalGroup = true, FdcFocusTraversalPolicy traversalPolicy = FdcFocusTraversalPolicy.widgetOrder})
-
Creates a FdcFocusOptions.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- traversalPolicy → FdcFocusTraversalPolicy
-
Traversal policy used by the generated FocusTraversalGroup.
final
- wrapTraversalGroup → bool
-
When true, the FDC scope wraps its child in a Flutter
FocusTraversalGroup.
final
Methods
-
copyWith(
{bool? wrapTraversalGroup, FdcFocusTraversalPolicy? traversalPolicy}) → FdcFocusOptions - Creates a copy with selected values replaced.
-
createTraversalPolicy(
) → FocusTraversalPolicy - Creates the Flutter traversal policy represented by traversalPolicy.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override