FdcGridCellStyle class
Visual style applied to data cells in a column.
Constructors
- FdcGridCellStyle({TextStyle? textStyle, Color? backgroundColor, Alignment? alignment})
-
Creates a FdcGridCellStyle.
const
Properties
- alignment → Alignment?
-
Optional alignment override for this value.
final
- backgroundColor → Color?
-
Optional background color override for this value.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle?
-
Optional text style override for this value.
final
Methods
-
copyWith(
{TextStyle? textStyle, Color? backgroundColor, Alignment? alignment}) → FdcGridCellStyle - Creates a copy with selected values replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override