FdcGridColumnGroupStyle class

Visual styling for a single FdcGridColumnGroup header cell.

Values are optional and override the shared group styling from the shared grid header group style only for the group that owns this style object.

Constructors

FdcGridColumnGroupStyle({Color? backgroundColor, TextStyle? textStyle, Alignment? alignment, EdgeInsetsGeometry? padding, Color? bottomSeparatorColor, Color? verticalSeparatorColor, double? verticalSeparatorInset})
Creates a FdcGridColumnGroupStyle.
const

Properties

alignment Alignment?
Alignment used by this group header label.
final
backgroundColor Color?
Background color used by this group header cell.
final
bottomSeparatorColor Color?
Bottom separator color used by this group header cell.
final
hashCode int
The hash code for this object.
no setteroverride
padding EdgeInsetsGeometry?
Padding used inside this group header cell.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle?
Text style used by this group header label.
final
verticalSeparatorColor Color?
Trailing vertical separator color used by this group header cell.
final
verticalSeparatorInset double?
Symmetric inset used above and below this group's trailing separator.
final

Methods

copyWith({Color? backgroundColor, TextStyle? textStyle, Alignment? alignment, EdgeInsetsGeometry? padding, Color? bottomSeparatorColor, Color? verticalSeparatorColor, double? verticalSeparatorInset}) FdcGridColumnGroupStyle
Creates a copy with selected values replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override