FdcGridColumnPinProperties extension

Adds grid column pin properties convenience APIs.

on

Properties

isEnd bool

Available on FdcGridColumnPin, provided by the FdcGridColumnPinProperties extension

Whether this mode pins the column to the logical end edge.
no setter
isFixed bool

Available on FdcGridColumnPin, provided by the FdcGridColumnPinProperties extension

Whether this mode prevents the user from unpinning the column.
no setter
isPinned bool

Available on FdcGridColumnPin, provided by the FdcGridColumnPinProperties extension

Whether this mode places the column in either pinned region.
no setter
isStart bool

Available on FdcGridColumnPin, provided by the FdcGridColumnPinProperties extension

Whether this mode pins the column to the logical start edge.
no setter