focusColumn method
Moves grid focus to the column identified by columnId.
Returns false when the column cannot be focused in the current layout.
Implementation
bool focusColumn(String columnId) {
return _requireAttached(_focusColumn).call(columnId);
}