FdcGridCustomItem class
Fully custom widget item for a grid toolbar or status bar.
- Inheritance
-
- Object
- FdcGridItem
- FdcGridCustomItem
Constructors
- FdcGridCustomItem({String? id, bool visible = true, FdcGridItemPlacement placement = FdcGridItemPlacement.end, required WidgetBuilder builder})
-
Creates a FdcGridCustomItem.
const
Properties
- builder → WidgetBuilder
-
Builds the custom widget rendered for this item.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
Optional stable identifier for locating or customizing this item.
finalinherited
- placement → FdcGridItemPlacement
-
Placement zone used by the host when arranging this item.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visible → bool
-
Whether this item participates in the host toolbar or status bar.
finalinherited
Methods
-
buildItem(
BuildContext context) → Widget -
Builds a host-independent item.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited