groupVerticalSeparatorInset property
Symmetric inset used above and below vertical group header separators.
When omitted, the group header uses verticalSeparatorInset. Set to zero to render group separators as flat full-height grid lines.
Implementation
final double? groupVerticalSeparatorInset;