textStyle property
Default text style used by grid header labels.
When omitted, the grid derives the same default from the ambient theme as before this style grouping: TextTheme.labelLarge unchanged.
Implementation
final TextStyle? textStyle;
Default text style used by grid header labels.
When omitted, the grid derives the same default from the ambient theme as before this style grouping: TextTheme.labelLarge unchanged.
final TextStyle? textStyle;