FdcGridItem class
Base class for items rendered inside a grid toolbar or status bar.
Constructors
- FdcGridItem({String? id, bool visible = true, FdcGridItemPlacement placement = FdcGridItemPlacement.end})
-
Creates a FdcGridItem.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
Optional stable identifier for locating or customizing this item.
final
- placement → FdcGridItemPlacement
-
Placement zone used by the host when arranging this item.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visible → bool
-
Whether this item participates in the host toolbar or status bar.
final
Methods
-
buildItem(
BuildContext context) → Widget - Builds a host-independent item.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited