FdcGridPageSizeSelector class
Selects the dataset page size while preserving the first visible global record offset where possible.
- Inheritance
-
- Object
- FdcGridItem
- FdcGridPageSizeSelector
Constructors
-
FdcGridPageSizeSelector({String? id, bool visible = true, FdcGridItemPlacement placement = FdcGridItemPlacement.end, String label = '', List<
int> options = const <int>[100, 500, 1000, 5000, 10000]}) - Creates a FdcGridPageSizeSelector.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
Optional stable identifier for locating or customizing this item.
finalinherited
- label → String
-
Display label shown to the user.
final
-
options
→ List<
int> -
Options used by this configuration.
final
- placement → FdcGridItemPlacement
-
Placement zone used by the host when arranging this item.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visible → bool
-
Whether this item participates in the host toolbar or status bar.
finalinherited
Methods
-
buildForDataSet(
BuildContext context, FdcDataSet dataSet) → Widget -
Builds this paging item for the current
dataSetpaging state. -
buildItem(
BuildContext context) → Widget -
Builds a host-independent item.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited