FdcGridPagingNavigator.input constructor
const
FdcGridPagingNavigator.input({})
Creates a FdcGridPagingNavigator.
Implementation
const FdcGridPagingNavigator.input({
super.id,
super.visible,
super.placement = FdcGridItemPlacement.end,
this.pageLabel,
this.pageCountLabel,
this.showFirstLastButtons = true,
this.showPreviousNextButtons = true,
this.allowPageInput = true,
}) : _style = _FdcGridPageNavigatorStyle.input,
/// Maximum number of numbered page buttons shown at once.
visiblePageCount = 5,
/// Shows first and last page boundaries around the numbered page window.
showBoundaryPages = true;