Lightweight, read-only row callback context used by FdcGrid callbacks.
It deliberately does not expose a Map<String, Object?> storage contract.
Use valueOf or the [] operator to read field values by name.
Properties
-
fieldNames
→ List<
String> -
Field names available through this context.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- rowIndex → int
-
Zero-based row index in the current grid view.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
containsField(
String fieldName) → bool -
Whether
fieldNameis available through this context. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
valueOf(
String fieldName) → Object? -
Returns the value of
fieldName, ornullwhen its value is null.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String fieldName) → Object? -
Returns the value of
fieldName.