FdcGridRowIndicatorOptions class
Selects which status, numbering, and row-selection affordances appear in the row indicator.
Constructors
- FdcGridRowIndicatorOptions({bool showRecordStatus = true, bool showRowNumbers = false, bool showRowSelect = false})
-
Creates a FdcGridRowIndicatorOptions.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showRecordStatus → bool
-
Shows the current record state indicator, such as edit or insert status.
final
- showRowNumbers → bool
-
Shows row numbers in the leading row indicator area.
final
- showRowSelect → bool
-
Shows row-selection controls in the leading row indicator area.
final
- visible → bool
-
Whether at least one row-indicator element is enabled.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override