buildItem method
Builds a host-independent item.
Grid-runtime items such as search, export, status text, progress, and paging are dispatched by their host shell before this fallback is used.
Implementation
@override
Widget buildItem(BuildContext context) {
return SizedBox(
width: width,
child: Center(
child: Container(
width: thickness,
height: height,
color: color ?? Theme.of(context).dividerColor,
),
),
);
}