backgroundColor property
Background color used for the grid viewport surface, including the empty body area below the last rendered data row.
Implementation
final Color? backgroundColor;
Background color used for the grid viewport surface, including the empty body area below the last rendered data row.
final Color? backgroundColor;