borderColor property

Color? borderColor
final

Color used for the outer border around the grid control.

Defaults to the same system light gray used by internal grid lines.

Implementation

final Color? borderColor;