selectedCellBackgroundColor property

Color? selectedCellBackgroundColor
final

Background color used by the active/current grid cell.

Defaults to transparent so the active cell does not introduce a fill color unless the grid style/theme explicitly asks for one.

Implementation

final Color? selectedCellBackgroundColor;