FdcGridSummary class
Configuration for the grid summary region and aggregate presentation.
Constructors
- FdcGridSummary({bool visible = true, FdcGridSummaryStyle style = const FdcGridSummaryStyle()})
-
Creates a FdcGridSummary.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → FdcGridSummaryStyle
-
Visual styling applied to the summary component.
final
- visible → bool
-
Controls whether the grid summary component may be rendered.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override