backgroundColor property
Background color used by the grid summary row panel.
When omitted, the grid resolves this to the grid viewport background so the summary row reads as part of the data body.
Implementation
final Color? backgroundColor;
Background color used by the grid summary row panel.
When omitted, the grid resolves this to the grid viewport background so the summary row reads as part of the data body.
final Color? backgroundColor;