FdcGridThemes class
Built-in FdcGrid theme presets.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- black → const FdcGridThemeData
- High-contrast dark preset with near-black surfaces.
- dark → const FdcGridThemeData
- Dark theme preset for grids embedded in dark application surfaces.
- light → const FdcGridThemeData
- Soft neutral light grid theme with a subtle grey application-surface look.
- white → const FdcGridThemeData
- Pure white grid theme preserving the historical FDC light defaults.