FdcGridToolbar class
Configuration for the optional toolbar displayed with an FdcGrid.
Constructors
-
FdcGridToolbar({bool visible = true, FdcGridToolbarStyle? style, List<
FdcGridItem> items = const <FdcGridItem>[FdcGridSearchBar()]}) -
Creates a FdcGridToolbar.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
items
→ List<
FdcGridItem> -
Ordered toolbar item list.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → FdcGridToolbarStyle?
-
Visual styling applied to the toolbar component.
final
- visible → bool
-
Controls whether the toolbar component is rendered.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override