compareTo method
Compares this object to another object.
Returns a value like a Comparator when comparing this to other.
That is, it returns a negative integer if this is ordered before other,
a positive integer if this is ordered after other,
and zero if this and other are ordered together.
The other argument must be a value that is comparable to this object.
Implementation
@override
int compareTo(FdcGuid other) {
var result = _a.compareTo(other._a);
if (result != 0) {
return result;
}
result = _b.compareTo(other._b);
if (result != 0) {
return result;
}
result = _c.compareTo(other._c);
if (result != 0) {
return result;
}
return _d.compareTo(other._d);
}