FdcKeyboardShortcut class final
Framework-neutral keyboard shortcut used by FDC public APIs.
Constructors
- FdcKeyboardShortcut(FdcKeyboardKey key, {bool control = false, bool alt = false, bool shift = false, bool meta = false})
-
Creates a FdcKeyboardShortcut.
const
Properties
- alt → bool
-
Whether the Alt modifier is required.
final
- control → bool
-
Whether the Control modifier is required.
final
- displayLabel → String
-
Human-readable shortcut label suitable for tooltips and menus.
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- key → FdcKeyboardKey
-
Keyboard key associated with this shortcut.
final
- meta → bool
-
Whether the Meta modifier is required.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shift → bool
-
Whether the Shift modifier is required.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- f2 → const FdcKeyboardShortcut
- Default value for f2.
- f4 → const FdcKeyboardShortcut
- Default value for f4.