FdcLocalizations class

Flutter Localizations integration for FDC components.

Constructors

FdcLocalizations(Locale locale, FdcTranslations translations)
Creates FDC localizations for locale.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
locale Locale
Locale used to resolve translations.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translations FdcTranslations
Resolved FDC translations.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

maybeOf(BuildContext context) FdcLocalizations?
Returns FDC localizations, or null when the app did not register the FDC delegate.
of(BuildContext context) FdcLocalizations
Returns FDC localizations from the nearest Localizations widget.

Constants

delegate → const LocalizationsDelegate<FdcLocalizations>
Default FDC localization delegate.
supportedLocales → const List<Locale>
Built-in FDC locales.