FdcMenuAction class

A selectable menu entry that invokes an action callback.

Use actions for commands that should run immediately when the user selects the entry.

Inheritance

Constructors

FdcMenuAction({required String text, IconData? icon, String? shortcutText, bool enabled = true, VoidCallback? onPressed})
Creates a FdcMenuAction.
const

Properties

enabled bool
Whether this feature is enabled.
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
Optional icon shown with the item.
final
onPressed VoidCallback?
Callback invoked when the item is activated.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcutText String?
Optional shortcut hint shown next to the item.
final
text String
Text displayed to the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited