FdcRowAction class
A standardized row-level action rendered by FdcActionColumn.
Constructors
- FdcRowAction({required IconData icon, String? tooltip, FdcRowActionCallback? onPressed, FdcRowActionPredicate? enabled, FdcRowActionPredicate? visible, bool activateRowOnPressed = true, Color? color, Color? disabledColor})
-
Creates a FdcRowAction.
const
- FdcRowAction.delete({String? tooltip = deleteTooltip, FdcRowActionPredicate? enabled, FdcRowActionPredicate? visible, bool activateRowOnPressed = false, Color? color = const Color(0xFFD32F2F), Color? disabledColor})
-
Creates a built-in delete action.
const
Properties
- activateRowOnPressed → bool
-
Whether a custom action should activate its row before onPressed.
final
- color → Color?
-
Optional icon color override.
final
- disabledColor → Color?
-
Optional disabled icon color override.
final
- enabled → FdcRowActionPredicate?
-
Optional per-row enabled predicate.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
Icon displayed for this action.
final
- onPressed → FdcRowActionCallback?
-
Custom command executed when this action is pressed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tooltip → String?
-
Optional tooltip displayed for the action button.
final
- visible → FdcRowActionPredicate?
-
Optional per-row visibility predicate.
final
Methods
-
invoke(
FdcRowActionContext context) → void -
Executes this action for
contextwhen it is enabled. -
isEnabled(
FdcRowActionContext context) → bool -
Resolves whether this action is enabled for
context. -
isVisible(
FdcRowActionContext context) → bool -
Resolves whether this action is visible for
context. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- deleteTooltip → const String
- Default tooltip for the built-in delete row action.