color property

Color? color
final

Optional icon color override.

The built-in delete action uses a destructive red color by default. Pass another color, including colors from the application theme, to override action-level styling.

Implementation

final Color? color;