FdcRowActionContext class
Context passed to row actions rendered by FdcActionColumn.
Constructors
- FdcRowActionContext({required BuildContext buildContext, required FdcDataSet dataSet, required FdcGridRowContext row, required int rowIndex, required int? sourceRowIndex, required int? recordId, required int columnIndex, required bool dataSetReadOnly, required bool activateRow(), required bool deleteRow(), required void handleControlPointerDown(PointerDownEvent event)})
-
Creates a FdcRowActionContext.
const
Properties
- buildContext → BuildContext
-
Flutter build context for the action cell.
final
- columnIndex → int
-
Visual column index of the action column.
final
- dataSet → FdcDataSet
-
Dataset displayed by the owning grid.
final
- dataSetReadOnly → bool
-
Whether the owning dataset is currently read-only.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- recordId → int?
-
Stable dataset record id for the current row, when available.
final
- row → FdcGridRowContext
-
Read-only row value accessor for the current row.
final
- rowIndex → int
-
Visual row index in the current grid view.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceRowIndex → int?
-
Source dataset row index for rowIndex, when available.
final
Methods
-
activateRow(
) → bool - Activates this action's row in the grid/dataset.
-
deleteRow(
) → bool - Deletes this action's row through the owning grid/dataset pipeline.
-
handleControlPointerDown(
PointerDownEvent event) → void - Marks a pointer down as belonging to an in-cell action control.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
tryValueOf<
V> (String fieldName) → V? -
Reads another field value when it is assignable to
V. -
valueOf<
V> (String fieldName) → V? - Reads another field value from the same row.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited