FdcSearchMode enum
Global dataset search matching mode.
Search is a dataset view criterion that is AND-combined with active filters. Modes define how the search text is matched across the configured fields.
Values
- phrase → const FdcSearchMode
-
A whole phrase must be contained in at least one searchable field.
- allWords → const FdcSearchMode
-
Every token must be contained somewhere across the searchable fields.
- anyWord → const FdcSearchMode
-
At least one token must be contained somewhere across the searchable fields.
- exactPhrase → const FdcSearchMode
-
A whole field value must exactly equal the phrase.
- startsWith → const FdcSearchMode
-
At least one searchable field must start with the phrase.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FdcSearchMode> - A constant List of the values in this enum, in order of their declaration.