FdcSortOrderStep class

Direction step returned while composing a fluent dataset sort.

Properties

ascending FdcSortBuilder
Adds ascending ordering for the pending field.
no setter
descending FdcSortBuilder
Adds descending ordering for the pending field.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited