FdcSubMenu class

A menu entry that opens a nested collection of child entries.

Inheritance

Constructors

FdcSubMenu({required String text, required List<FdcMenuEntry> children, IconData? icon, bool enabled = true})
Creates a FdcSubMenu.
const

Properties

children List<FdcMenuEntry>
Child entries rendered inside this item.
final
enabled bool
Whether this feature is enabled.
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
Optional icon shown with the item.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Text displayed to the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited