FdcTextExportPayload class final
UTF-8 text payload returned by text-based export writers.
- Inheritance
-
- Object
- FdcExportPayload
- FdcTextExportPayload
Constructors
- FdcTextExportPayload(String value)
-
Creates a FdcTextExportPayload.
const
Properties
- bytes → Uint8List
-
Serialized bytes for this payload.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
Text content, or
nullwhen the payload is binary.no setteroverride - value → String
-
Unencoded text content.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited