FdcUpdateMode enum
How dataset changes are persisted through an adapter.
Values
- cachedUpdates → const FdcUpdateMode
-
Changes are kept locally until applyUpdates() is called.
This is an explicit opt-in mode for batch editing/review workflows.
- immediate → const FdcUpdateMode
-
Posted and deleted changes are automatically applied through the adapter.
This is the default dataset update mode.
Because adapters are asynchronous, post/delete remain synchronous local dataset operations and schedule the apply operation immediately after the local change is committed. Use onError/onWorkError to observe persistence failures.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FdcUpdateMode> - A constant List of the values in this enum, in order of their declaration.