FdcGridColumnLayoutSnapshot class

Persisted layout state for one grid column.

Constructors

FdcGridColumnLayoutSnapshot({required String id, required int order, required double width, required bool visible, required FdcGridColumnPin pin, required FdcAggregate? summaryAggregate})
Creates a FdcGridColumnLayoutSnapshot.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Identifier for this object.
final
order int
Zero-based runtime order of the column.
final
pin FdcGridColumnPin
Persisted column pinning mode.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summaryAggregate FdcAggregate?
Persisted runtime summary aggregate override, when any.
final
visible bool
Persisted column visibility.
final
width double
Persisted column width.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited