rowIndicator property
Row indicator component configuration.
The row indicator is visible by default and can show record status, row numbers, row selection, and the main grid menu.
Implementation
final FdcGridRowIndicator rowIndicator;
Row indicator component configuration.
The row indicator is visible by default and can show record status, row numbers, row selection, and the main grid menu.
final FdcGridRowIndicator rowIndicator;