FdcGridLayoutSnapshot class

Serializable snapshot of user-adjustable grid layout state.

Constructors

FdcGridLayoutSnapshot({required List<FdcGridColumnLayoutSnapshot> columns, required bool headerFiltersVisible})
Creates a FdcGridLayoutSnapshot.
const

Properties

columns List<FdcGridColumnLayoutSnapshot>
Per-column layout state in runtime column order.
final
hashCode int
The hash code for this object.
no setterinherited
headerFiltersVisible bool
Whether the header filter row was visible when the snapshot was captured.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited