FdcGridRangeSelectionContextMenuContext class

Context passed when building range-selection context-menu entries.

Constructors

FdcGridRangeSelectionContextMenuContext({required bool copyEnabled, required bool pasteEnabled, required VoidCallback onCopy, required VoidCallback onPaste})
Creates a FdcGridRangeSelectionContextMenuContext.
const

Properties

copyEnabled bool
Whether the host currently allows copying the selected range.
final
hashCode int
The hash code for this object.
no setterinherited
onCopy VoidCallback
Invokes the host-owned copy command for the current normalized range.
final
onPaste VoidCallback
Invokes the host-owned paste command for the current normalized range.
final
pasteEnabled bool
Whether the host currently allows pasting clipboard data into the range.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited