copyEnabled property
Whether the host currently allows copying the selected range.
Builders should disable or omit copy commands when this is false.
Implementation
final bool copyEnabled;
Whether the host currently allows copying the selected range.
Builders should disable or omit copy commands when this is false.
final bool copyEnabled;