pasteEnabled property
Whether the host currently allows pasting clipboard data into the range.
Builders should disable or omit paste commands when this is false.
Implementation
final bool pasteEnabled;
Whether the host currently allows pasting clipboard data into the range.
Builders should disable or omit paste commands when this is false.
final bool pasteEnabled;