reset method
Notifies the feature that the attached grid reset its range state.
Immutable feature configuration objects can ignore this. Feature implementations that keep external state may use it to synchronize with dataset, column, and lifecycle changes.
Implementation
void reset({bool rebuild = true}) {}