hasExpandedDetailRows property

bool get hasExpandedDetailRows

Whether the attached grid currently contains one or more expanded detail rows.

Features can use this state when determining whether range interaction or projection is compatible with the current row layout.

Implementation

bool get hasExpandedDetailRows;