FdcGridRangeSelectionOverlayColumnGeometry class
Column geometry snapshot used by the range-selection overlay.
Constructors
- FdcGridRangeSelectionOverlayColumnGeometry({required int sourceColumnIndex, required double offset, required double width})
-
Creates a FdcGridRangeSelectionOverlayColumnGeometry.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- offset → double
-
Horizontal offset of the column inside its viewport band.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceColumnIndex → int
-
The source column index.
final
- width → double
-
Rendered width of the source column.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited