shouldProcessGlobalModifierEvent abstract method
Whether a global modifier transition should update range-selection input state.
Implementations use the supplied editor, focus, hover, and enablement state to avoid intercepting modifier input owned by active text editors.
Implementation
bool shouldProcessGlobalModifierEvent({
required bool enabled,
required bool modifierKey,
required bool pressed,
required FdcGridCellRef? hoverCell,
required bool hasActiveCellEditor,
required bool hasGridTextInputFocus,
});